********************************************************************
***      Definition of sets in Db                                ***
***                                                              ***
********************************************************************

***      Declaration of sets     ***

Sets
         input_no   plant number in input table
         /1*12414/
*OBS update in Input_db the range that is included from db

         in_no(input_no) total number of plants in db
         /1*12224/

         fill_no(input_no) numbers for created filling capacities
         /12225*12414/

         Time    years included in model
         /1900*2070/

         inv_year(Time)  investment made year
         /1900*2050/

         T(Time) Time period investigated [Year]
         /2010*2050/
         start(T)        Initial year
         /2010/

         db_prop         Power plant properties included in CSS Db
         /location_no             Db country
         fuel_no                 Fuel in Db
         commission              year of commission
         decommission            year of decommission
         status_db               Status in db
         eta_el                  electrical efficiency from db
         eta_tot                 total efficiency
         plant_type_db           database type
         capacity_el             net electrical capacity
         capacity_boiler         net thermal capacity
         capacity_heat           net heat capacity
         decom_db                stated decommission year in Db
         latitude
         longitude
         nutsnumber              Nutsregion code at nuts2 level
/

         geography(db_prop)
         /latitude
         longitude
         nutsnumber              Nutsregion code at nuts2 level
/

         eval_prop(db_prop)
         /commission             year of commission
         capacity_el             net electrical capacity
         capacity_boiler         net thermal capacity
         capacity_heat           net heat capacity/

         cap_prop(eval_prop)
         /capacity_el             net electrical capacity
         capacity_boiler         net thermal capacity
         capacity_heat           net heat capacity/

          regions         all geographical entities
         /Austria, Belgium, Bosnia, Bulgaria, Croatia, Cyprus, Czech_Republic, Denmark, Estonia,
         Finland, France, Germany, Greece, Hungary, Iceland, Ireland, Italy,
         Latvia, Lithuania, Luxembourg, Macedonia, Malta, Netherlands, Norway, Poland,
         Portugal, Romania, Slovakia, Slovenia, Spain, Sweden, Switzerland, UK
$include %include_path%regional/regions.inc
         /
         dbcountry(regions)          countries in CSS DB
         /Austria, Belgium, Bosnia, Bulgaria, Croatia, Cyprus, Czech_Republic, Denmark, Estonia,
         Finland, France, Germany, Greece, Hungary, Iceland, Ireland, Italy,
         Latvia, Lithuania, Luxembourg, Macedonia, Malta, Netherlands, Norway, Poland,
         Portugal, Romania, Slovakia, Slovenia, Spain, Sweden, Switzerland, UK/

         EPODreg(regions)        53 European regions defined by bottlenecks
         /
$include %include_path%regional/regions.inc
         /

         country_to_EPODreg(dbcountry,EPODreg)   defines EPODreg in respective countries
         /Austria.(AT)
         Belgium.(BE)
         Bosnia.(BO)
         Bulgaria.(BG)
         Croatia.(CR)
         Cyprus.(CY)
         Czech_Republic.(CZ)
         Germany.(DE1,DE2,DE3,DE4,DE5)
         Denmark.(DK1,DK2)
         Estonia.(EE)
         Finland.(FI)
        France.(FR1,FR2,FR3,FR4,FR5)
         Greece.(GR)
         Hungary.(HU)
         Iceland.(IS)
         Ireland.(IE)
        Italy.(IT1,IT2,IT3)
        Latvia.(LV)
        Lithuania.(LT)
        Luxembourg.(LU)
         Macedonia.(MC)
         Malta.(MT)
        Netherlands.(NL)
        Norway.(NO1,NO2,NO3)
        Poland.(PO1,PO2,PO3)
        Portugal.(PT)
         Romania.(RO)
         Slovakia.(SK)
         Slovenia.(SI)
         Spain.(ES1,ES2,ES3,ES4)
        Sweden.(SE1,SE2,SE3,SE4)
         Switzerland.(CH)
        UK.(UK1,UK2,UK3)
         /

$ifi %regional%==yes $goto ELINregional
         I_reg(dbcountry)           Investigated regions(s). use (*) to exclude region from simultation.
         /
*$ontext
         Austria
         Belgium
         Bulgaria
*         Cyprus
         Czech_Republic
         Denmark
         Estonia
         Finland
         France
         Germany
         Greece
         Hungary
         Ireland
         Italy
         Latvia
         Lithuania
         Luxembourg
         Malta
         Netherlands
         Norway
         Poland
         Portugal
         Romania
         Slovakia
         Slovenia
         Spain
*$offtext
         Sweden
         Switzerland
         UK
         /
$label ELINregional
$ifi %national%==yes $goto ELINnational
         I_reg(EPODreg)
         /
         AT
         BE
*        BO
         BG
*        CR
         CY
         CZ
         DE1,DE2,DE3,DE4,DE5
         DK1,DK2
         EE
         ES1,ES2,ES3,ES4
         FI
         FR1,FR2,FR3,FR4,FR5
         EL
         HU
         IE
*         IS
         IT1,IT2,IT3
         LV
         LT
         LU
*        MC
         MT
         NL
         NO1,NO2,NO3
         PO1,PO2,PO3
         PT
         RO
         SE1,SE2,SE3,SE4
         SI
         SK
         CH
         UK1,UK2,UK3
         /
$label ELINnational
$onempty
         nuc_phase_out(I_reg)
         /
$ifi %regional%==yes $goto NucOutRegional
         Belgium
         Germany
         Switzerland
$label NucOutRegional
$ifi %national%==yes $goto NucOutNational
*         BE
*         DE1,DE2,DE3,DE4,DE5
*         CH
$label NucOutNational
/
$offempty
         all_en_type             All energy types and technologies included in Db
         /B      Lignite
         H       Hard coal
         G       Natural gas
         O       Oil
         P       Peat
         W       Biomass
         WA      Waste
         U       Uranium
         WON     Wind onshore
         WOFF    Wind offshore
         RO      Run of river
         PS      Pumped storage
         BCCS    Lignite CCS
         HCCS    Hard coal CCS
         GCCS    Gas CCS
         BWCCS   Lignite co-fired with biomass CCS
         HWCCS   Hard coal co-fired with biomass CCS
         PV      Solar PVs
         STH     Solar thermal concentration heat
         T       Tidal barges
         WV      Wave power
         Small_hydro     small scale hydro
         GEO     Geothermal
         HY      Hydrogen
         Z       Unknown
         ICE     interconnector export
         ICI     interconnector import
/

         en_type(all_en_type)    Energy types and technologies applied in current model
         /B      Lignite
         H       Hard coal
         G       Natural gas
         O       Oil
         P       Peat
         W       Biomass
         WA      Waste
         U       Uranium
         WON     Wind onshore
         WOFF    Wind offshore
         RO      Run of river
         PS      Pumped storage
         BCCS    Lignite CCS
         HCCS    Hard coal CCS
         GCCS    Gas CCS
         BWCCS   Lignite co-fired with biomass CCS
         HWCCS   Hard coal co-fired with biomass CCS
         PV      Solar PVs
         STH     Solar thermal concentration heat
         T       Tidal barges
         WV      Wave power
         Small_hydro     small scale hydro
         GEO     Geothermal
/

         thermal(en_type)        Fuels used in the system
         /B      Lignite
         H       Hard coal
         G       Gas
         O       Oil
         P       Peat
         W       Biomass
         WA      Waste
         U       Nuclear/

         thermal_ex_nuce(thermal)        Fuels used in the system
         /B      Lignite
         H       Hard coal
         G       Gas
         O       Oil
         P       Peat
         W       Biomass
         WA      Waste
/
         nuce(thermal)
         /U
/

         C_emitting(thermal)     Fossil fuels emitting carbon
         /B       Lignite
         H       Hard coal
         G       Gas
         O       Oil
         P       Peat
         WA      Waste
/

         CCS_fuels(thermal)      Fuels used in CCS technologies
         /B      Lignite
         H       Hard coal
         G       Gas
         W       Biomass
/

         hydro(en_type)          Types of hydro power
         /RO     run of river
         PS      pumped storage
/

         wind(en_type)
         /WON    Wind onshore
         WOFF    wind offshore
/

         RES(en_type)          Renewables
         /W      Biomass
         WA      Waste
         WON     Wind onshore
         WOFF    Wind Offshore
         RO      Hydro run of river
         PS      Hydro pumped storage/

         plant_type            Type of facility in terms of Condensing plant or back pressure or DH
         /Condens        Condensing plant
         CHP             Combined heat and power
         BP              Back pressure/

         geothermal(all_en_type)
         /GEO/

         heat(plant_type)      Heat producing types
         /CHP             Combined heat and power
         BP              Back pressure/

         CON(plant_type)       /Condens/
         B_P(plant_type)       /BP/
         C_HP(plant_type)      /CHP/

         others(en_type)  new types of capacities present in CSS db or present system
         /PV     Solar PVs
         STH     Solar thermal power
         T   Tidal barges
         Wv    Wave power
         Small_hydro     small scale hydro/


         CCS(en_type)             Types of CCS technologies
         /BCCS   Lignite CCS
         HCCS    Hard coal CCS
         GCCS    Gas CCS
         BWCCS   Lignite co-fired with biomass CCS
         HWCCS   Hard coal co-fired with biomass CCS/

         CCS_bio(CCS)
         /BWCCS   Lignite co-fired with biomass CCS
         HWCCS   Hard coal co-fired with biomass CCS/

         status_Db               Stated status in Db
         /OPR    Operating
         PEAK    peak generation
         RES     Reserv capacity
         CON     Under construction
         APPR    Approaved for construction
         PLN     Planned and applied for
         ADD     added capacities by clean program/

         modelled_status(status_Db)      included in modelling
         /OPR    Operating
         PEAK    peak generation
         RES     Reserv capacity
         CON     Under construction
         APPR    Approaved for construction
         ADD     added capacities by clean program/

         in_use(status_Db)
         /OPR    Operating
         PEAK    peak generation
         RES     Reserv capacity
         ADD     Added capacity/

         new_cap(status_Db)
         /CON     Under construction
         APPR    Approaved for construction
         PLN     Planned and applied for/

         new(status_Db)          Taken in as probable capacities to be built
         /CON     Under construction
         APPR    Approaved for construction/
;

set nuts2
$offlisting
$include %include_path%nuts2.inc
Set country_to_nuts2(dbcountry,nuts2)
$include %include_path%country_to_nuts2.inc
Set EPODreg_to_nuts2(EPODreg,nuts2)
$include %include_path%region_to_nuts2.inc
Set regions_to_nuts2(regions,nuts2)
$include %include_path%/regional/Ireg_to_nuts2.inc
$onlisting

alias (T,year);
*alias (Time,inv_year);
