********************************************************************
***      Definition of regional parameters in model                       ***
***                                                              ***
********************************************************************
*----------------------Share per region---------------------------------------------------------------------
* The load share is defined by the regional gdp divided by national gdp. GDP from EUROSTAT 2008.

Parameter gdp_nuts2(nuts2)      'the gdp in 2008 from EUROSTAT'
$include %include_path%Regional/gdp_nuts2.inc

Parameter gdp_region(EPODreg) 'gdp which pertain to each region';
gdp_region(I_reg)=sum(nuts2$EPODreg_to_nuts2(I_reg,nuts2),gdp_nuts2(nuts2));
*Regional GDP for Norway from Statistics Norway 2004.
gdp_region('NO3')=13715+32159+48065;
gdp_region('NO2')=24810+64614;
gdp_region('NO1')=1180824-gdp_region('NO2')-gdp_region('NO3');
gdp_region(I_reg)$(gdp_region(I_reg)=0)=1;
Parameter load_share(EPODreg)   'regional share of national total';
load_share(I_reg)=gdp_region(I_reg)/(sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),sum(EPODreg$country_to_EPODreg(dbcountry,EPODreg),gdp_region(EPODreg))));

Parameter area(nuts2)    'the area per nuts2'
*$call=xls2gms "i=%include_path%Regional/Area_NUTS2.xlsx" R=Sheet2!A1:B200 "O=%include_path%Regional/area1.inc"
/
$include "%include_path%Regional/area1.inc";
/;
$onmulti
Parameter area(nuts2)    'the area per nuts2'
*$call=xls2gms "i=%include_path%Regional/Area_NUTS2.xlsx" R=Sheet1!A1:B117 "O=%include_path%Regional/area2.inc"
/
$include "%include_path%Regional/area2.inc"
/;
$offmulti
Parameter area_region(EPODreg);
area_region(I_reg)=sum(nuts2$EPODreg_to_nuts2(I_reg,nuts2),area(nuts2));
area_region(I_reg)$(area_region(I_reg)=0)=1;
Parameter area_share(regions)   'regional share of national area';
area_share(I_reg)=area_region(I_reg)/(sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),sum(EPODreg$country_to_EPODreg(dbcountry,EPODreg),area_region(EPODreg))));
*---------------------------------------------------------------------------------------------------------------------------------
*********DEMAND******************
demand(I_reg,T)$(gdp_region(I_reg)>0)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),demand_ref(dbcountry,T))*load_share(I_reg);
Parameter demand_in(I_reg,start);
demand_in(I_reg,start)=demand(I_reg,start);
*demand_GR(I_reg,T)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),demand_GR_ref(dbcountry,T));
load_profile(an_hour,I_reg)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),load_profile_ref(an_hour,dbcountry));

demand_RES_in(I_reg,RES_years) = sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),Demand_RES_in_ref(dbcountry,RES_years));

CO2_reference(I_reg,CO2_years)$(gdp_region(I_reg)>0)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),CO2_reference_ref(dbcountry,CO2_years))*load_share(I_reg);

demand_heat_in(I_reg,eco_years)$(gdp_region(I_reg)>0)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),demand_heat_in_ref(dbcountry,eco_years))*load_share(I_reg);

*CHP_indicator_in(I_reg,EET_years)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),CHP_indicator_in_ref(dbcountry,EET_years));
CHP_fraction_in(I_reg,eco_years)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),CHP_fraction_in_ref(dbcountry,eco_years));

demand_BP_in(I_reg,former_start)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),demand_BP_in_ref(dbcountry,former_start))*load_share(I_reg);

heat_load_profile(an_hour,I_reg)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),heat_load_profile_ref(an_hour,dbcountry));

**********FUEL*********************
Cum_bio_supply2020(I_reg,bio_class)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),Cum_bio_supply2020_ref(dbcountry,bio_class))*area_share(I_reg);
Cum_bio_supply2050(I_reg,bio_class)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),Cum_bio_supply2050_ref(dbcountry,bio_class))*area_share(I_reg);

Cum_waste_supply2020(I_reg,waste_class)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),Cum_waste_supply2020_ref(dbcountry,waste_class))*area_share(I_reg);
Cum_waste_supply2050(I_reg,waste_class)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),Cum_waste_supply2050_ref(dbcountry,waste_class))*area_share(I_reg);
Fc_national_waste(I_reg,waste_class)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),Fc_national_waste_ref(dbcountry,waste_class));

fuel_pot(I_reg,thermal_pot)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),fuel_pot_ref(dbcountry,thermal_pot))*area_share(I_reg);
BP_E_in(I_reg,B_P)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),BP_E_in_ref(dbcountry,B_P))*load_share(I_reg);
valid_CCS(I_reg,"BCCS",CON)=no;
valid_CCS(I_reg,"BWCCS",CON)=no;
valid_CCS(I_reg,"BCCS",CON)$(fuel_pot(I_reg,"B") gt 0)=yes;
valid_CCS(I_reg,"BWCCS",CON)$(fuel_pot(I_reg,"B") gt 0)=yes;
*****THERMAL****
****WIND***********
****HYDRO*******
*One region per country gets all hydro power capacity.
Set hydro_region(EPODreg) 'regions with hydro power' /SE1,SE2,SE3,SE4,NO1,NO2,NO3,FI,CH,AT,IT1,FR4,DE1,UK2,IE,EE,LV,LT,PO1,RO,BG,CZ,ES2,PT,DK2,NL,BE,SI/;

hydro_stat(hydro_region,hydro)=sum(dbcountry$country_to_EPODreg(dbcountry,hydro_region),hydro_stat_ref(dbcountry,hydro));
*Sweden: Data on capacity per river from "Vattenkraft" Svensk Energi, 2001.+4% corresponding to recent turbine upgrades
*Norway: data on total capacity per county for NO3 (Finnmark,Troms,Nordland) and NO2 (Trondelag) from NVE annual report 2010.
*NO1 has total hydro capacity from Nordel 2008 subtracted with NO2 and NO3 (assuming the little thermal is in NO1).
hydro_stat('SE4','RO')=(4350+50+1020+1740)*1.04/1000;
hydro_stat('SE3','RO')=(2530+2090+600)*1.04/1000;
hydro_stat('SE2','RO')=(800+1080+158+400+350+158)*1.04/1000;
hydro_stat('SE1','RO')=130*1.04/1000;
hydro_stat('NO2','RO')=(728+1055)/1000;
hydro_stat('NO3','RO')=(314+574+3284)/1000;
hydro_stat('NO1','RO')=29474/1000-hydro_stat('NO2','RO')-hydro_stat('NO3','RO');
hydro_stat('FI','RO')=3097;

hydro_prod(hydro_region,hydro_class)=sum(dbcountry$country_to_EPODreg(dbcountry,hydro_region),hydro_prod_ref(dbcountry,hydro_class));
* Regional share based on WILMAR/KTH ris-r-1443
* Average year: SE 73TWh NO 120TWh FI 12TWh. Dry year: SE 51 TWh NO 104 TWh FI 12 TWh Wet year: SE 91 TWh NO 143 TWh FI 12 TWh
hydro_prod('SE4','reg')$(hydro_stat('SE4','RO')<>0)=hydro_stat('SE4','RO')/(hydro_stat('SE4','RO')+hydro_stat('SE3','RO'))*hydro_prod_ref('Sweden','reg')*0.91;
hydro_prod('SE3','reg')$(hydro_stat('SE3','RO')<>0)=hydro_stat('SE3','RO')/(hydro_stat('SE4','RO')+hydro_stat('SE3','RO'))*hydro_prod_ref('Sweden','reg')*0.91;
hydro_prod('SE2','reg')=0.08*hydro_prod_ref('Sweden','reg');
hydro_prod('SE1','reg')=0.01*hydro_prod_ref('Sweden','reg');
hydro_prod('NO1','reg')=0.73*hydro_prod_ref('Norway','reg');
hydro_prod('NO2','reg')=0.19*hydro_prod_ref('Norway','reg');
hydro_prod('NO3','reg')=0.08*hydro_prod_ref('Norway','reg');
hydro_prod('SE4','run_riv')$(hydro_stat('SE4','RO')<>0)=hydro_stat('SE4','RO')/(hydro_stat('SE4','RO')+hydro_stat('SE3','RO'))*hydro_prod_ref('Sweden','run_riv')*0.91;
hydro_prod('SE3','run_riv')$(hydro_stat('SE3','RO')<>0)=hydro_stat('SE3','RO')/(hydro_stat('SE4','RO')+hydro_stat('SE3','RO'))*hydro_prod_ref('Sweden','run_riv')*0.91;
hydro_prod('SE2','run_riv')=0.08*hydro_prod_ref('Sweden','run_riv');
hydro_prod('SE1','run_riv')=0.01*hydro_prod_ref('Sweden','run_riv');
hydro_prod('NO1','run_riv')=0.73*hydro_prod_ref('Norway','run_riv');
hydro_prod('NO2','run_riv')=0.19*hydro_prod_ref('Norway','run_riv');
hydro_prod('NO3','run_riv')=0.08*hydro_prod_ref('Norway','run_riv');

hydro_prod_max(regions,"reg",T)=0;
hydro_prod_max(dbcountry,hydro_class,T)=hydro_prod_ref(dbcountry,hydro_class);
hydro_prod_max(hydro_region,hydro_class,T)=sum(dbcountry$country_to_EPODreg(dbcountry,hydro_region),hydro_prod_ref(dbcountry,hydro_class));

hydro_prod_max("Norway","reg",T)$((T_num(T) lt 2020) and(T_num(T) gt 2014))=hydro_prod_ref("Norway","reg")+(5/(2020-T_num(T)));
hydro_prod_max("Norway","reg",T)$((T_num(T) lt 2030) and(T_num(T) ge 2020))=hydro_prod_max("Norway","reg",'2019')+(5/(2030-T_num(T)));
hydro_prod_max("Norway","reg",T)$(T_num(T) ge 2030)=hydro_prod_max("Norway","reg",'2029');
hydro_prod_max("Norway","run_riv",T)$((T_num(T) lt 2020) and(T_num(T) gt 2014))=hydro_prod_ref("Norway","run_riv")+(1.5/(2020-T_num(T)));
hydro_prod_max("Norway","run_riv",T)$((T_num(T) lt 2030) and(T_num(T) ge 2020))=hydro_prod_max("Norway","run_riv",'2019')+((3-1.5)/(2030-T_num(T)));
hydro_prod_max("Norway","run_riv",T)$(T_num(T) ge 2030)=hydro_prod_max("Norway","run_riv",'2029');

hydro_prod_max('SE4','reg',T)$(hydro_stat('SE4','RO')<>0)=hydro_stat('SE4','RO')/(hydro_stat('SE4','RO')+hydro_stat('SE3','RO'))*hydro_prod_max('Sweden','reg',T)*0.91;
hydro_prod_max('SE3','reg',T)$(hydro_stat('SE3','RO')<>0)=hydro_stat('SE3','RO')/(hydro_stat('SE4','RO')+hydro_stat('SE3','RO'))*hydro_prod_max('Sweden','reg',T)*0.91;
hydro_prod_max('SE2','reg',T)=0.08*hydro_prod_max('Sweden','reg',T);
hydro_prod_max('SE1','reg',T)=0.01*hydro_prod_max('Sweden','reg',T);
hydro_prod_max('NO1','reg',T)=0.73*hydro_prod_max('Norway','reg',T);
hydro_prod_max('NO2','reg',T)=0.19*hydro_prod_max('Norway','reg',T);
hydro_prod_max('NO3','reg',T)=0.08*hydro_prod_max('Norway','reg',T);
hydro_prod_max('SE4','run_riv',T)$(hydro_stat('SE4','RO')<>0)=hydro_stat('SE4','RO')/(hydro_stat('SE4','RO')+hydro_stat('SE3','RO'))*hydro_prod_max('Sweden','run_riv',T)*0.91;
hydro_prod_max('SE3','run_riv',T)$(hydro_stat('SE3','RO')<>0)=hydro_stat('SE3','RO')/(hydro_stat('SE4','RO')+hydro_stat('SE3','RO'))*hydro_prod_max('Sweden','run_riv',T)*0.91;
hydro_prod_max('SE2','run_riv',T)=0.08*hydro_prod_max('Sweden','run_riv',T);
hydro_prod_max('SE1','run_riv',T)=0.01*hydro_prod_max('Sweden','run_riv',T);
hydro_prod_max('NO1','run_riv',T)=0.73*hydro_prod_max('Norway','run_riv',T);
hydro_prod_max('NO2','run_riv',T)=0.19*hydro_prod_max('Norway','run_riv',T);
hydro_prod_max('NO3','run_riv',T)=0.08*hydro_prod_max('Norway','run_riv',T);
hydro_prod_max(dbcountry,hydro_class,T)=0;

*All the hydropower capacity to the region with the production.
residual_P_hydro(I_reg,'RO',T)$(hydro_region(I_reg) and not (country_to_EPODreg('Sweden',I_reg) or country_to_EPODreg('Norway',I_reg)))=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),sum(EPODreg$country_to_EPODreg(dbcountry,EPODreg),residual_P_hydro(I_reg,'RO',T)));
residual_P_hydroclass(I_reg,'run_riv',T)$((hydro_prod(I_reg,'run_riv')+hydro_prod(I_reg,'reg')) gt 0)=(hydro_prod(I_reg,'run_riv')/(hydro_prod(I_reg,'run_riv')+hydro_prod(I_reg,'reg')))*residual_P_hydro(I_reg,'RO',T);
residual_P_hydroclass(I_reg,'reg',T)$((hydro_prod(I_reg,'run_riv')+hydro_prod(I_reg,'reg')) gt 0)=(hydro_prod(I_reg,'reg')/(hydro_prod(I_reg,'run_riv')+hydro_prod(I_reg,'reg')))*residual_P_hydro(I_reg,'RO',T);

residual_P_hydroclass('SE4','run_riv',T)$((hydro_prod('SE4','run_riv')+hydro_prod('SE4','reg')) gt 0)=(hydro_prod('SE4','run_riv')/(hydro_prod('SE4','run_riv')+hydro_prod('SE4','reg')))*0.91*hydro_stat('SE4','RO')/(hydro_stat('SE4','RO')+hydro_stat('SE3','RO'))*(residual_P_hydro('SE4','RO',T)+residual_P_hydro('SE3','RO',T)+residual_P_hydro('SE2','RO',T)+residual_P_hydro('SE1','RO',T));
residual_P_hydroclass('SE4','reg',T)$((hydro_prod('SE4','run_riv')+hydro_prod('SE4','reg')) gt 0)=(hydro_prod('SE4','reg')/(hydro_prod('SE4','run_riv')+hydro_prod('SE4','reg')))*0.91*hydro_stat('SE4','RO')/(hydro_stat('SE4','RO')+hydro_stat('SE3','RO'))*(residual_P_hydro('SE4','RO',T)+residual_P_hydro('SE3','RO',T)+residual_P_hydro('SE2','RO',T)+residual_P_hydro('SE1','RO',T));
residual_P_hydroclass('SE3','run_riv',T)$((hydro_prod('SE3','run_riv')+hydro_prod('SE3','reg')) gt 0)=(hydro_prod('SE3','run_riv')/(hydro_prod('SE3','run_riv')+hydro_prod('SE3','reg')))*0.91*hydro_stat('SE3','RO')/(hydro_stat('SE3','RO')+hydro_stat('SE4','RO'))*(residual_P_hydro('SE4','RO',T)+residual_P_hydro('SE3','RO',T)+residual_P_hydro('SE2','RO',T)+residual_P_hydro('SE1','RO',T));
residual_P_hydroclass('SE3','reg',T)$((hydro_prod('SE3','run_riv')+hydro_prod('SE3','reg')) gt 0)=(hydro_prod('SE3','reg')/(hydro_prod('SE3','run_riv')+hydro_prod('SE3','reg')))*0.91*hydro_stat('SE3','RO')/(hydro_stat('SE3','RO')+hydro_stat('SE4','RO'))*(residual_P_hydro('SE4','RO',T)+residual_P_hydro('SE3','RO',T)+residual_P_hydro('SE2','RO',T)+residual_P_hydro('SE1','RO',T));
residual_P_hydroclass('SE2','run_riv',T)$((hydro_prod('SE2','run_riv')+hydro_prod('SE2','reg')) gt 0)=(hydro_prod('SE2','run_riv')/(hydro_prod('SE2','run_riv')+hydro_prod('SE2','reg')))*0.08*(residual_P_hydro('SE4','RO',T)+residual_P_hydro('SE3','RO',T)+residual_P_hydro('SE2','RO',T)+residual_P_hydro('SE1','RO',T));
residual_P_hydroclass('SE2','reg',T)$((hydro_prod('SE2','run_riv')+hydro_prod('SE2','reg')) gt 0)=(hydro_prod('SE2','reg')/(hydro_prod('SE2','run_riv')+hydro_prod('SE2','reg')))*0.08*(residual_P_hydro('SE4','RO',T)+residual_P_hydro('SE3','RO',T)+residual_P_hydro('SE2','RO',T)+residual_P_hydro('SE1','RO',T));
residual_P_hydroclass('SE1','run_riv',T)$((hydro_prod('SE1','run_riv')+hydro_prod('SE1','reg')) gt 0)=(hydro_prod('SE1','run_riv')/(hydro_prod('SE1','run_riv')+hydro_prod('SE1','reg')))*0.01*(residual_P_hydro('SE4','RO',T)+residual_P_hydro('SE3','RO',T)+residual_P_hydro('SE2','RO',T)+residual_P_hydro('SE1','RO',T));
residual_P_hydroclass('SE1','reg',T)$((hydro_prod('SE1','run_riv')+hydro_prod('SE1','reg')) gt 0)=(hydro_prod('SE1','reg')/(hydro_prod('SE1','run_riv')+hydro_prod('SE1','reg')))*0.01*(residual_P_hydro('SE4','RO',T)+residual_P_hydro('SE3','RO',T)+residual_P_hydro('SE2','RO',T)+residual_P_hydro('SE1','RO',T));
residual_P_hydroclass('NO1','run_riv',T)$((hydro_prod('NO1','run_riv')+hydro_prod('NO1','reg')) gt 0)=(hydro_prod('NO1','run_riv')/(hydro_prod('NO1','run_riv')+hydro_prod('NO1','reg')))*0.73*(residual_P_hydro('NO2','RO',T)+residual_P_hydro('NO1','RO',T)+residual_P_hydro('NO3','RO',T));
residual_P_hydroclass('NO1','reg',T)$((hydro_prod('NO1','run_riv')+hydro_prod('NO1','reg')) gt 0)=(hydro_prod('NO1','reg')/(hydro_prod('NO1','run_riv')+hydro_prod('NO1','reg')))*0.73*(residual_P_hydro('NO2','RO',T)+residual_P_hydro('NO1','RO',T)+residual_P_hydro('NO3','RO',T));
residual_P_hydroclass('NO2','run_riv',T)$((hydro_prod('NO2','run_riv')+hydro_prod('NO2','reg')) gt 0)=(hydro_prod('NO2','run_riv')/(hydro_prod('NO2','run_riv')+hydro_prod('NO2','reg')))*0.19*(residual_P_hydro('NO2','RO',T)+residual_P_hydro('NO1','RO',T)+residual_P_hydro('NO3','RO',T));
residual_P_hydroclass('NO2','reg',T)$((hydro_prod('NO2','run_riv')+hydro_prod('NO2','reg')) gt 0)=(hydro_prod('NO2','reg')/(hydro_prod('NO2','run_riv')+hydro_prod('NO2','reg')))*0.19*(residual_P_hydro('NO2','RO',T)+residual_P_hydro('NO1','RO',T)+residual_P_hydro('NO3','RO',T));
residual_P_hydroclass('NO3','run_riv',T)$((hydro_prod('NO3','run_riv')+hydro_prod('NO3','reg')) gt 0)=(hydro_prod('NO3','run_riv')/(hydro_prod('NO3','run_riv')+hydro_prod('NO3','reg')))*0.08*(residual_P_hydro('NO2','RO',T)+residual_P_hydro('NO1','RO',T)+residual_P_hydro('NO3','RO',T));
residual_P_hydroclass('NO3','reg',T)$((hydro_prod('NO3','run_riv')+hydro_prod('NO3','reg')) gt 0)=(hydro_prod('NO3','reg')/(hydro_prod('NO3','run_riv')+hydro_prod('NO3','reg')))*0.08*(residual_P_hydro('NO2','RO',T)+residual_P_hydro('NO1','RO',T)+residual_P_hydro('NO3','RO',T));



EPH_LF(an_hour,I_reg)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),EPH_LF_ref(an_hour,dbcountry));

***Solar***
valid_solar_sites(solar_sites)=no;
*valid_solar_sites(solar_sites)$(solar_pot(solar_sites) gt 0) = yes;
loop(I_reg,
         valid_solar_sites(solar_sites)$(solar_sites_to_regions(solar_sites,I_reg) and (solar_pot_buildings(solar_sites) gt 0 or solar_pot_centralized(solar_sites) gt 0))=yes;
)
;

****OTHERS*****
EPO_LF1(an_hour,I_reg,others)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),EPO_LF1_ref(an_hour,dbcountry,others));
others_full_Lh(I_reg,others)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),others_full_Lh_ref(dbcountry,others));
small_RO_pot(I_reg,small_RO)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),small_RO_pot_ref(dbcountry,small_RO));

***GEO-THERMAL***
***CCS***
CO2_store_cost(I_reg,store_prop)=sum(dbcountry$country_to_EPODreg(dbcountry,I_reg),CO2_store_cost_ref(dbcountry,store_prop));
***INTERCONNECTORS*****
* Use capacity limitations between regions based on Pmax=U1*U2/Xtot
* For p.u. calculations the following base is applied:
* Ubase=100 kV Sbase=100 MVA Zbase=100

Set HVDC(exp_region,imp_region)  'pairs of regions coupled by HVDC only'
$include %include_path%regional/HVDC.inc

Table lines400(exp_region,imp_region) 'number of 400kV lines between regions'
$if %update_scenario% == "yes" $call =xls2gms "I=%include_path%regional/number_of_lines_v2.xlsx" R=400lines!A1:BA53 "O=%include_path%regional/400lines.inc"
$include %include_path%regional/400lines.inc
;

Table lines200(exp_region,imp_region)   'number of 200kV lines between regions'
$if %update_scenario% == "yes" $call =xls2gms "I=%include_path%regional/number_of_lines_v2.xlsx" R=200lines!A1:BA53 "O=%include_path%regional/200lines.inc"
$include %include_path%regional/200lines.inc
;

*Table DClines(exp_region,imp_region)   'number of DC lines between regions'
*$if %update_scenario% == "yes" $call =xls2gms "I=%include_path%regional/number_of_lines_v2.xlsx" R=DClines!A1:BA53 "O=%include_path%regional/DClines.inc"
*$include %include_path%regional/DClines.inc
*;

Parameter cabel400(exp_region,imp_region) 'number of 400kV cables between regions';
cabel400(exp_region,imp_region)=0;
cabel400('SE1','DK1')=2;

Table distance(exp_region,imp_region)        'distance between pairs of regions in km'
*$call =xls2gms "I=D:\users\edqvist.net\Documents\ELIN_EPOD\DCflow\data\number_of_lines2.xls" R=distance!A1:BA53 "O=D:\users\edqvist.net\Documents\ELIN_EPOD\DCflow\distance.inc"
$include %include_path%regional/distance_v2.inc
;
*Default on distance is +inf
*Electric distance is typically 60% of geographical distance due to series compensators.
*distance(exp_region,imp_region)=distance(exp_region,imp_region)*0.6;

*Symmetric lines and distances.
lines400(exp_region,imp_region)$(lines400(exp_region,imp_region)<lines400(imp_region,exp_region))=lines400(imp_region,exp_region);
lines200(exp_region,imp_region)$(lines200(exp_region,imp_region)<lines200(imp_region,exp_region))=lines200(imp_region,exp_region);
*DClines(exp_region,imp_region)$(DClines(exp_region,imp_region)<DClines(imp_region,exp_region))=DClines(imp_region,exp_region);
cabel400(exp_region,imp_region)$(cabel400(exp_region,imp_region)<cabel400(imp_region,exp_region))=cabel400(imp_region,exp_region);
distance(exp_region,imp_region)$(distance(exp_region,imp_region)>distance(imp_region,exp_region))=distance(imp_region,exp_region);

Set neighbours(exp_region,imp_region)        'regions which have/could have ac connections';
neighbours(exp_region,imp_region)=no;
neighbours(exp_region,imp_region)$(lines400(exp_region,imp_region)>0 or lines400(imp_region,exp_region)>0)=yes;
neighbours(exp_region,imp_region)$(lines200(exp_region,imp_region)>0 or lines200(imp_region,exp_region)>0)=yes;
neighbours('FI','NO3')=yes;
neighbours('SE1','DK1')=yes;
neighbours('DE2','BE')=yes;
neighbours('DE3','BE')=yes;
neighbours('FR4','LU')=yes;
neighbours('PO2','SK')=yes;
neighbours('DE4','PO3')=yes;
neighbours(exp_region,imp_region)$(neighbours(imp_region,exp_region))=yes;

Scalar pi;
pi=3.14159265;
Scalar linereactance400   'reactance per 400kV line and km, from "Power system stability and control" by Kundur Prabha';
linereactance400=0.367;
Scalar linereactance200   'reactance per 200kV line and km, from "Power system stability and control" by Kundur Prabha';
linereactance200=0.488;
Scalar cabelreactance400   'reactance per 400kV cable and km, from "Power system stability and control" by Kundur Prabha';
cabelreactance400=0.2454;
*Scalar linereactanceDC      'reactance per DC line and km';
Parameter reactance400(exp_region,imp_region)       'total reactance in 400 kV lines between regions in p.u. 1/xtot=1/x1+1/x2+1/x3+...';
reactance400(exp_region,imp_region)$(lines400(exp_region,imp_region)<>0 and distance(exp_region,imp_region)<inf)=(1/1600)*(distance(exp_region,imp_region)*linereactance400)/lines400(exp_region,imp_region);
Parameter reactance200(exp_region,imp_region)       'total reactance in 200 kV lines between regions in p.u. 1/xtot=1/x1+1/x2+1/x3+...';
reactance200(exp_region,imp_region)$(lines200(exp_region,imp_region)<>0 and distance(exp_region,imp_region)<inf)=(1/400)*(distance(exp_region,imp_region)*linereactance200)/lines200(exp_region,imp_region);
Parameter reactance400cabel(exp_region,imp_region)       'total reactance in 400 kV cables between regions in p.u. 1/xtot=1/x1+1/x2+1/x3+...';
reactance400cabel(exp_region,imp_region)$(cabel400(exp_region,imp_region)<>0 and distance(exp_region,imp_region)<inf)=(1/1600)*(distance(exp_region,imp_region)*cabelreactance400)/cabel400(exp_region,imp_region);
*Parameter reactanceDC(exp_region,imp_region)       'total reactance in DC lines between regions in p.u. 1/xtot=1/x1+1/x2+1/x3+...';
*reactanceDC(exp_region,imp_region)=(1/???)*(DClines(exp_region,imp_region)/(distance(exp_region,imp_region)*linereactanceDC(exp_region,imp_region)));
Parameter reactance(exp_region,imp_region)       'total reactance between regions in p.u. 1/xtot=1/x1+1/x2+1/x3+...';
reactance(exp_region,imp_region)$(distance(exp_region,imp_region) ge 1000000)=INF;
reactance(exp_region,imp_region)$(lines400(exp_region,imp_region)=0 and lines200(exp_region,imp_region)=0 and cabel400(exp_region,imp_region)=0)=INF;
reactance(exp_region,imp_region)$(reactance400(exp_region,imp_region)<>0 and reactance200(exp_region,imp_region)<>0)=1/((1/reactance400(exp_region,imp_region))+(1/reactance200(exp_region,imp_region)));
reactance(exp_region,imp_region)$(reactance400(exp_region,imp_region)<>0 and reactance200(exp_region,imp_region)=0)=reactance400(exp_region,imp_region);
reactance(exp_region,imp_region)$(reactance400(exp_region,imp_region)=0 and reactance200(exp_region,imp_region)<>0)=reactance200(exp_region,imp_region);
* If NTC value is known but calculated exchange_cap_dc will not correspond, NTC value can be used to assess reactance:
reactance('SE1','DK1')=1/17*pi/2*0.7;
* Symmetric reactance.
*reactance(exp_region,imp_region)$(reactance(exp_region,imp_region)>10 and reactance(imp_region,exp_region)<10)=reactance(imp_region,exp_region);
reactance(exp_region,imp_region)$(reactance(exp_region,imp_region)>reactance(imp_region,exp_region))=reactance(imp_region,exp_region);
* In case of cables (not finished here!)
*reactance(exp_region,imp_region)$(reactance400cabel(exp_region,imp_region)<>0)=1/((1/reactance(exp_region,imp_region))+(1/reactance400cabel(exp_region,imp_region)));

Parameter
         exchange_cap_dc(exp_region,imp_region) 'maxixmum AC transmission capacity between two regions [MW]'
         hvdc_capacity(exp_region,imp_region)    maximum HVDC transmission capacity between two regions [MW]
;
exchange_cap_dc(exp_region,imp_region)=0;
hvdc_capacity(exp_region,imp_region) = 0;
exchange_cap_dc(exp_region,imp_region)$(reactance(exp_region,imp_region)<>0)=(1/reactance(exp_region,imp_region))*100*pi/2*0.7;

*For HVDC capacities are given and define upper limit on exchange [MW]:
hvdc_capacity('DK1','DK2')=590;
hvdc_capacity('SE2','DK2')=740;
hvdc_capacity('NO1','DK2')=1000;
hvdc_capacity('NO1','NL')=700;
hvdc_capacity('NL','UK1')=2000;
hvdc_capacity('FR5','UK1')=2000;
hvdc_capacity('UK1','NL')=1000;
hvdc_capacity('FI','EE')=1000;
hvdc_capacity('SE2','LT')=700;
hvdc_capacity('SE1','PO3')=600;
hvdc_capacity('SE2','FI')=1300;
hvdc_capacity('DE4','DK1')=600;
hvdc_capacity('SE1','DE4')=600;
hvdc_capacity('IT3','EL')=500;
hvdc_capacity('FR5','UK1')=2000;
* Missing capacity between british islands
hvdc_capacity('UK1','IE')=500;
hvdc_capacity('UK2','UK3')=500;
*Investments in HVDC lines are defined as:
*exchange_cap_dc(export_reg,import_reg)=exchange_cap_dc(export_reg,import_reg)+newcapacity;

* Make both AC and DC capacities symmetric
exchange_cap_dc(exp_region,imp_region)$(exchange_cap_dc(imp_region,exp_region)>exchange_cap_dc(exp_region,imp_region))=exchange_cap_dc(imp_region,exp_region);
hvdc_capacity(exp_region,imp_region)$(hvdc_capacity(imp_region,exp_region)>hvdc_capacity(exp_region,imp_region))=hvdc_capacity(imp_region,exp_region);

EPCON(exp_region,imp_region)=exchange_cap_dc(exp_region,imp_region)/1000 + hvdc_capacity(exp_region,imp_region)/1000;
Scalar OHACcostkm        'MEUR per GW and km for new overhead AC connection capacity';
OHACcostkm=600/1000;
NP_trade_Ic_ref(export_reg,import_reg)$(neighbours(export_reg,import_reg) and distance(export_reg,import_reg)<10000)=distance(export_reg,import_reg)*OHACcostkm;
Scalar SCDCcostkm        'MEUR per GW and km for new DC submarine cable capacity';
SCDCcostkm=715/1000;
Scalar substations       'MEUR per GW for two dc substations';
substations=60000/1000;
NP_trade_Ic_ref(export_reg,import_reg)$((not neighbours(import_reg,export_reg)) and distance(export_reg,import_reg)<10000)=distance(export_reg,import_reg)*SCDCcostkm+substations;
NP_trade_Ic(export_reg,import_reg,year)=NP_trade_Ic_ref(export_reg,import_reg);
*--------------------------------------------------------------------------------------------------------------------------------------------------------
