********************************************************************
***      Definition of sets in model                             ***
***                                                              ***
********************************************************************


Sets
         EET_years(Time)         Years represented in European Energy and Transport
         /2000
         2005
         2010
         2015
         2020
         2025
         2030/

         WEO_years(Time)
         /2000
         2010
         2015
         2020
         2025
         2030
         2035/

         RES_years(Time)
         /2005
         2010*2020
         2025
         2030
         2040
         2050/

         former_start(Time)
         /2003/

         eco_years(Time)            Start and end year for which heat demand is given in ecoheatcool
         /2003
         2050/

         CO2_years(Time)
         /1990
         2003/

         TL_year                Technical lifetime years
         /x-1*x-200/

         TWh/TWh1*TWh5000/

         solar_sites

         solar_sites_to_nuts2 (solar_sites, nuts2)
         solar_sites_to_regions(solar_sites,regions)

         nuclear_inv(I_reg)

         inv_prop                Cost property of investment
         /site   Cost of site
         plant   Cost of plant/

         OM_prop                Cost property of O&M
         /fix    Fixed O&M costs
         var     Variable O&M costs/

         eta_prop                factors defining the efficiency curves for electric efficiency
         /a      Carnot efficiency
         b       shaping factor
         c       Initial curve year
         d       shaping factor/

         statistics      mean value for a ten year period and standard deviation
         /mean
         st_dev/

         Base_load(thermal)
         /B
         H
         WA
         U/

         thermal_pot(thermal)
         /B
         W
         WA/

         small_RO(others)
         /small_hydro/

         store_prop      Storage and transport cost labels
         /transport
         storage/

         bio_class       Biomass cost classes
         /bio_class1*bio_class11/

         Waste_class
         /waste_class1*waste_class11/

         wind_class
         /low    low lands
         up      highlands
         off     offshore/

         wind_systems

         wind_type
         /
         onwind10       onshore wind class with CF 10 percent
         onwind125        onshore wind class with CF 12.5 percent
         onwind15        onshore wind class with CF 15 percent
         onwind175        onshore wind class with CF 17.5 percent
         onwind20       onshore wind class with CF 20 percent
         onwind25        onshore wind class with CF 25 percent
         onwind30        onshore wind class with CF 30 percent
         onwind35        onshore wind class with CF 35 percent
         offwind         offshore wind class with CF tot average of sites availableon
         /
         onwind(wind_type)
         /
         onwind10       onshore wind class with CF 10 percent
         onwind125        onshore wind class with CF 12.5 percent
         onwind15        onshore wind class with CF 15 percent
         onwind175        onshore wind class with CF 17.5 percent
         onwind20       onshore wind class with CF 20 percent
         onwind25        onshore wind class with CF 25 percent
         onwind30        onshore wind class with CF 30 percent
         onwind35        onshore wind class with CF 35 percent
         /

         solar_systems

         solar_type
*         /
*         opt_csi
*         two_csi
*         opt_cd_te
*         two_cd_te
*/

         building_solar_type(solar_type)
         solar_type_to_solar_systems(solar_type,solar_systems)


         Silicon(solar_type)
*         /
*         opt_csi
*         two_csi
*         /

         thin_film(solar_type)
*         /
*         opt_cd_te
*         two_cd_te
*         /

         non_PV(others)
         /STH     Solar thermal power
         T   Tidal barges
         Wv    Wave power
         Small_hydro     small scale hydro/

         hydro_class
         /run_riv        run of river
         reg             regulated hydro/

         peak_gas
         /GT     gas turbines low eff
         /

         sector               electricity demand sectors
         /
                 residential
                 commercial
         /

         storage_systems
*         storage_type         types of storage capacity
*         /
*                 battery
*                thermal
*         /

         tenyear_period       10 year investment periods of inv_year ex 1900-1909
         /10year_1*10year_15/

         fiveyear_period        5 year investment periods of T ex 2010-2014
         /5year_1*5year_8/

         valid_thermal(I_reg,thermal,plant_type)

         valid_CCS(I_reg,CCS,plant_type)


         an_hour
         /hour1*hour8760/

         Winter(an_hour)
         /hour1*hour1416,hour8017*hour8760/

         Spring(an_hour)
         /hour1417*hour3624/

         Summer(an_hour)
         /hour3625*hour5832/

         Autumn(an_hour)
         /hour5833*hour8016/

         Weekend(an_hour)

         Weekday(an_hour)

         Day(an_hour)

         Night(an_hour)
$ontext
         WiWDD(an_hour)
         WiWDN(an_hour)
         WiWED(an_hour)
         WiWEN(an_hour)

         SpWDD(an_hour)
         SpWDN(an_hour)
         SpWED(an_hour)
         SpWEN(an_hour)

         SuWDD(an_hour)
         SuWDN(an_hour)
         SuWED(an_hour)
         SuWEN(an_hour)

         AuWDD(an_hour)
         AuWDN(an_hour)
         AuWED(an_hour)
         AuWEN(an_hour)
$offtext

         timestep_1(I_reg,an_hour)
         timestep_2(I_reg,an_hour)
         timestep_3(I_reg,an_hour)
         timestep_4(I_reg,an_hour)
         timestep_5(I_reg,an_hour)
         timestep_6(I_reg,an_hour)
         timestep_7(I_reg,an_hour)
         timestep_8(I_reg,an_hour)
         timestep_9(I_reg,an_hour)
         timestep_10(I_reg,an_hour)
         timestep_11(I_reg,an_hour)
         timestep_12(I_reg,an_hour)
         timestep_13(I_reg,an_hour)
         timestep_14(I_reg,an_hour)
         timestep_15(I_reg,an_hour)
         timestep_16(I_reg,an_hour)

         timestep_nuts2_1(nuts2,an_hour)
         timestep_nuts2_2(nuts2,an_hour)
         timestep_nuts2_3(nuts2,an_hour)
         timestep_nuts2_4(nuts2,an_hour)
         timestep_nuts2_5(nuts2,an_hour)
         timestep_nuts2_6(nuts2,an_hour)
         timestep_nuts2_7(nuts2,an_hour)
         timestep_nuts2_8(nuts2,an_hour)
         timestep_nuts2_9(nuts2,an_hour)
         timestep_nuts2_10(nuts2,an_hour)
         timestep_nuts2_11(nuts2,an_hour)
         timestep_nuts2_12(nuts2,an_hour)
         timestep_nuts2_13(nuts2,an_hour)
         timestep_nuts2_14(nuts2,an_hour)
         timestep_nuts2_15(nuts2,an_hour)
         timestep_nuts2_16(nuts2,an_hour)

         Time_step
         /Step_1
         Step_2
         Step_3
         Step_4
         Step_5
         Step_6
         Step_7
         Step_8
         Step_9
         Step_10
         Step_11
         Step_12
         Step_13
         Step_14
         Step_15
         Step_16/

         winter_steps(Time_step)
         /Step_1
         Step_2
         Step_3
         Step_4/

         summer_steps(Time_step)
         /Step_9
         Step_10
         Step_11
         Step_12/

;
* for the purpose of a daily balanced storage
$ontext
Set timetogether(time_step,time_step);
timetogether(time_step,time_step)=no;
timetogether('Step_1','Step_2')=yes;
timetogether('Step_3','Step_4')=yes;
timetogether('Step_5','Step_6')=yes;
timetogether('Step_7','Step_8')=yes;
timetogether('Step_9','Step_10')=yes;
timetogether('Step_11','Step_12')=yes;
timetogether('Step_13','Step_14')=yes;
timetogether('Step_15','Step_16')=yes;
alias(timetogether_step,time_step);
$offtext

alias (T,year);
alias (T,year2);
alias (I_reg,II_reg);
alias (I_reg,import_reg,export_reg);
alias (regions,imp_region,exp_region);
alias (dbcountry,imp_country,exp_country);

sets
         valid_EP_trade(I_reg,import_reg)
         valid_NP_trade(I_reg,import_reg)
         valid_wind_type(nuts2,wind_type)
         valid_solar_sites(solar_sites)
;
*alias (bio_class,biomass_class);

nuclear_inv(I_reg) = not nuc_phase_out(I_reg);

* Load the set of solar sites
$gdxin %path%\solar_profiles.gdx
$loaddc solar_sites, solar_sites_to_nuts2
$gdxin

* loads the sets of solar technology types, systems types, their respective mapping, solar site names, and the mapping of solar sites to nuts2 regions
$gdxin %path%\solar_info.gdx
$loaddc solar_systems, solar_type, building_solar_type, solar_type_to_solar_systems
$gdxin

* loads the set of wind systems types
$gdxin %path%\wind_info.gdx
$loaddc wind_systems
$gdxin

* loads the set of storage systems types
$gdxin %path%\storage_info.gdx
$loaddc storage_systems
$gdxin

* Map solar sites to model region
loop(nuts2,
         solar_sites_to_regions(solar_sites,regions)$(regions_to_nuts2(regions,nuts2) and solar_sites_to_nuts2(solar_sites,nuts2))=yes;
);

valid_thermal(I_reg,thermal,plant_type)=yes;
valid_thermal(I_reg,"U",plant_type)=no;
valid_thermal(nuclear_inv,"U","condens")=yes;
valid_thermal(I_reg,"WA",B_P)=no;
*valid_thermal(I_reg,"WA","condens")=yes;
valid_thermal(I_reg,"P",plant_type)=no;
*valid_thermal(I_reg,"O",plant_type)=no;

valid_CCS(I_reg,CCS,plant_type)=no;
valid_CCS(I_reg,CCS,CON)=yes;
*valid_CCS("Sweden",CCS,CON)=no;
valid_CCS(I_reg,CCS,CON)$(country_num(I_reg) eq country_num("Norway"))=no;
valid_CCS(I_reg,"GCCS",CON)$(country_num(I_reg) eq country_num("Norway"))=yes;
valid_CCS(I_reg,CCS,CON)$(country_num(I_reg) eq country_num("Switzerland"))=no;

*$(not CCS_bio(CCS))
valid_CCS(I_reg,"BCCS",CON)$(country_num(I_reg) eq country_num("Austria"))=no;
valid_CCS(I_reg,"BWCCS",CON)$(country_num(I_reg) eq country_num("Austria"))=no;


scalar   Ir      Interest rate for economic calculations;

