classdef Expander < TurboMachine
    % Turbine A default expander object
    %   Simply calculates output based on an isentropic efficiency, a state
    %   in, and an output pressure.

    methods     
        function expander = Expander(eta)
%                 turbine.Eta = eta;
%                 turbine.calculate(stateIn,pressureOut)
            if nargin == 1
                expander.Eta = eta;
                expander.StateIn = [];
                expander.StateOut = [];
            elseif nargin > 1
                error('Too many inputs. Please specify 1 input, an efficiency')
            else
                error('Not enough inputs. Please specify 1 input, an efficiency')
            end
        end
            
        function work = getWork(expander,stateIn,pressureOut)
            if nargin ~= 3
                error('Please specify 3 inputs to the turbine.calculate function')
%                disp(['No turbine efficiency specified, using default of ' num2str(Turbine.getDefaultEta)])
%                turbine.Eta = Turbine.getDefaultEta;
            end
            expander.StateIn = stateIn;
            stateOutS = FluidState(expander.StateIn.FluidModel, 'entropy', expander.StateIn.Entropy, 'pressure', pressureOut);
            enthalpyOut = expander.Eta * (stateOutS.Enthalpy - expander.StateIn.Enthalpy) + expander.StateIn.Enthalpy;
            expander.StateOut = FluidState(expander.StateIn.FluidModel, 'enthalpy', enthalpyOut, 'pressure', pressureOut);
            work = (expander.StateIn.Enthalpy - expander.StateOut.Enthalpy);
          
        end
        
        function eta = getIsentropicEfficiency(expander)
            stateOutS = FluidState(expander.StateIn.FluidModel, 'entropy', expander.StateIn.Entropy, 'pressure', expander.StateOut.Pressure);
            eta = (expander.StateOut.Enthalpy - expander.StateIn.Enthalpy) / (stateOutS.Enthalpy - expander.StateIn.Enthalpy);
        end
    end
    methods (Static)
        %used to populate the efficiency edit boxes of the gui
        function eta = getDefaultEta()
            eta = 0.80;
        end
    end
end