classdef FluidHX < HeatExchanger
    %FLUIDHX A non-condensing fluid heat exchanger
    %   Used in a thermal system, for example, to provide process heat from
    %   a solar loop.
    
    properties
        StateIn
        StateOut
        Eta
    end
    
    methods
        function fluidHX = FluidHX(eta)
            if nargin == 0
                warning('Null input constructor call: FluidHX');
            elseif nargin == 1
                fluidHX.Eta = eta;
                fluidHX.StateIn = [];
                fluidHX.StateOut = [];
            else
                error('Not correct number of inputs. Please specify 1 input, an efficiency')
            end
        end
        
        %         function heat = getHeat(heatExchanger)
        %             heat = (heatExchanger.StateOut.Enthalpy - heatExchanger.StateIn.Enthalpy);
        %         end
        
        function heatOut = getHeat(fluidHX,stateIn,stateOut)
            fluidHX.StateIn = stateIn;
            fluidHX.StateOut = stateOut;
            heatOut = fluidHX.Eta*(fluidHX.StateIn.Enthalpy - fluidHX.StateOut.Enthalpy);
        end
    end
    
    methods (Static)
        %used to populate the efficiency edit boxes of the gui
        function eta = getDefaultEta()
            eta = 0.90;
        end
    end
    
end

