classdef FluidState < handle
    % Calculates fluid state of water only using steam tables
    % Units:
    % Temperature: C
    % Pressure: bar
    % Enthalpy: kJ/kg
    % Specific: entropy kJ/(kg C)
    % Specific: internal energy kJ/kg
    % Quality: (0-1)

    
    properties
        FluidModel
        Enthalpy
        Entropy
        InternalEnergy
        Pressure
        Quality
        Temperature
        Density
    end
    
    methods
        function state = FluidState(fluidModel, prop1name, prop1, prop2name, prop2)
             state.FluidModel = 'Water/Steam: X Steam';
            % fluid and two properties are specified
            if nargin == 5
                % remove whitespace from beginning and end of property
                % names and make lowercase and put into cell array with the
                % property value
                property1 = {lower(strtrim(prop1name)) prop1};
                property2 = {lower(strtrim(prop2name)) prop2};
                
                % Alphabetize property pairs and reassign the first
                % alphabetically to property1 if not already
                sortedPropNames = sort({property1{1} property2{1}});
                if strcmp(sortedPropNames{1}, property2{1})
                    tempVar = property1;
                    property1 = property2;
                    property2 = tempVar;
                end
                
                switch property1{1}
                    case 'enthalpy'
                        state.Enthalpy = property1{2};
                        switch property2{1}
                            case 'entropy'
                                state.Entropy = property2{2};
                                % to calculate Temperature based on
                                % enthalpy and entropy; units in C, kJ/kg,
                                % kJ/kg/C
                                state.Temperature = XSteam('T_hs',state.Enthalpy,state.Entropy);
                                % to calculate Pressure based on enthalpy
                                % and entropy; units in bar, kJ/kg, kJ/kg/C
                                state.Pressure = XSteam('p_hs',state.Enthalpy,state.Entropy);
%                                 state.Quality = XSteam('x_ph',state.Pressure,state.Enthalpy);
                                getStatePT();
                            case 'internal energy'
%                                 state.InternalEnergy = property2{2};
%                                 state.Temperature = 
%                                 [state.Temperature state.Pressure vapRatio liquidEnthalpy vaporEnthalpy liquidEnergy vaporEnergy liquidFractions vaporFractions] = stCALFlashHU(state.FluidModel, state.Enthalpy, state.InternalEnergy, [1 0], 1, 1, false);
%                                 state.Quality = vaporFractions(1);
%                                 getStatePT();
                                error('Must input an independent property other than %s', property2{1});
                            case 'pressure'
                                state.Pressure = property2{2};
%                                 [state.Temperature vapRatio liquidEnthalpy vaporEnthalpy liquidFractions vaporFractions] = stCALFlashHP(state.FluidModel, state.Pressure, state.Enthalpy, [1 0], 1, 1, false);
%                                 state.Quality = vaporFractions(1);
                                state.Temperature = XSteam('T_ph',state.Pressure,state.Enthalpy);
                                getStatePT();
                            case 'quality'
                                state.Quality = property2{2};
                                error('Must input an independent property other than %s', property2{1});
                            case 'temperature'
                                state.Temperature = property2{2};
                                error('Must input an independent property other than %s', property2{1});
%                                 getStatePT();
                            otherwise
                                error('Invalid Property Name: %s', property2{1});
                        end
                    case 'entropy'
                        state.Entropy = property1{2};
                        switch property2{1}
                            case 'internal energy'
                                state.InternalEnergy = property2{2};
                                error('Must input an independent property other than %s', property2{1});
%                                 getStatePT();
                            case 'pressure'
                                state.Pressure = property2{2};
                                state.Temperature = XSteam('T_ps',state.Pressure,state.Entropy);
                                state.Enthalpy = XSteam('h_ps',state.Pressure,state.Entropy);
                                getStatePT();
                            case 'quality'
                                state.Quality = property2{2};
                                error('Must input an independent property other than %s', property2{1});
                            case 'temperature'
                                state.Temperature = property2{2};
                                error('p(T,s) = no go')
%                                 getStatePT();
                            otherwise
                                error('Invalid Property Name: %s', property2{1});
                        end
                    case 'internal energy'
                        state.InternalEnergy = property1{2};
                        error('Must input an independent property other than %s', property2{1});
%                         switch property2{1}
%                             case 'pressure'
%                                 state.Pressure = property2{2};
%                                 [state.Temperature vapRatio liquidEnergy vaporEnergy liquidFractions vaporFractions] = stCALFlashUP(state.FluidModel, state.Pressure, state.InternalEnergy, [1 0], 1, 1, false);
%                                 state.Quality = vaporFractions(1);
%                                 getStatePT();
%                             case 'quality'
%                                 state.Quality = property2{2};
%                                 error('Must input an independent property other than %s', property2{1});
%                             case 'temperature'
%                                 state.Temperature = property2{2};
%                                 [state.Pressure vapRatio liquidEnergy vaporEnergy liquidFractions vaporFractions] = stCALFlashUT(state.FluidModel, state.Temperature, state.InternalEnergy, [1 0], 1, 1, false);
%                                 state.Quality = vaporFractions(1);
%                                 getStatePT();
%                             otherwise
%                                 error('Invalid Property Name: %s', property2{1});
%                         end
                    case 'pressure'
                        state.Pressure = property1{2};
                        switch property2{1}
                            case 'quality'
                                state.Quality = property2{2};
                                state.Enthalpy = XSteam('h_px',state.Pressure, state.Quality);
                                state.Temperature = XSteam('T_ph',state.Pressure,state.Enthalpy);
                                getStatePT();
                                warndlg('Note: Pressure and quality give saturation conditions and do not work for superheat or supercool')
                                
                            case 'temperature'
                                state.Temperature = property2{2};
                                getStatePT();
                            otherwise
                                error('Invalid Property Name: %s', property2{1});
                        end
                    case 'quality'
                        state.Quality = property1{2};
                        switch property2{1}
                            case 'temperature'
                                state.Temperature = property2{2};
                                error('Must input an independent property other than %s', property2{1});
%                                 getStatePT();
                            otherwise
                                error('Invalid Property Name: %s', property2{1});
                        end
                    otherwise
                        error('Invalid Property Name: %s', property1{1});
                end
                % fluid, one property (T or P), and phase are specified at
                % saturation
            elseif nargin == 4
                % remove whitespace from beginning and end of property
                % names and make lowercase and put into cell array with the
                % property value
                property = {lower(strtrim(prop1name)) prop1};
                phase = lower(strtrim(prop2name));
                switch property{1}
                    case 'pressure'
                        state.Pressure = property{2};
                        switch phase
                            case 'saturated liquid'
                                state.Temperature = XSteam('Tsat_p',state.Pressure);
                                state.Enthalpy = XSteam('hL_p',state.Pressure);
                                state.Quality = 0;
%                                 QualityCheck = XSteam('x_ph',state.Pressure,state.Enthalpy)
                                state.Entropy = XSteam('sL_p',state.Pressure);
                                state.InternalEnergy = XSteam('uL_p',state.Pressure);
                            case 'saturated vapor'
                                state.Temperature = XSteam('Tsat_p',state.Pressure);
                                state.Enthalpy = XSteam('hV_p',state.Pressure);
                                state.Quality = 1;
%                                 QualityCheck = XSteam('x_ph',state.Pressure,state.Enthalpy)
                                state.Entropy = XSteam('sV_p',state.Pressure);
                                state.InternalEnergy = XSteam('uV_p',state.Pressure);
                        end
                    case 'temperature'
                        state.Temperature = property{2};
                        switch phase
                            case 'saturated liquid'
                                state.Pressure = XSteam('psat_T',state.Temperature);
                                state.Enthalpy = XSteam('hL_p',state.Pressure);
                                state.Quality = 0;
%                                 QualityCheck = XSteam('x_ph',state.Pressure,state.Enthalpy)
                                state.Entropy = XSteam('sL_p',state.Pressure);
                                state.InternalEnergy = XSteam('uL_p',state.Pressure);
                            case 'saturated vapor'
                                state.Pressure = XSteam('psat_T',state.Temperature);
                                state.Enthalpy = XSteam('hV_p',state.Pressure);
                                state.Quality = 1;
%                                 QualityCheck = XSteam('x_ph',state.Pressure,state.Enthalpy)
                                state.Entropy = XSteam('sV_p',state.Pressure);
                                state.InternalEnergy = XSteam('uV_p',state.Pressure);
                        end
                    otherwise
                        error('Invalid Saturation State Specified %s', property{1});
                end
            else error('invalid number of arguments in function call: %d', nargin);
            end
            
            function getStatePT()
                if isempty(state.Enthalpy)
                    state.Enthalpy = XSteam('h_pT',state.Pressure,state.Temperature);
                end
                if isempty(state.Entropy)
                    state.Entropy = XSteam('s_ph',state.Pressure,state.Enthalpy);
                end
                if isempty(state.InternalEnergy)
                    state.InternalEnergy = XSteam('u_ph',state.Pressure,state.Enthalpy);
                end
                if isempty(state.Quality)
                    state.Quality = XSteam('x_ph',state.Pressure,state.Enthalpy);
                end
                if isempty(state.Density)
                    state.Density = XSteam('rho_ph',state.Pressure,state.Enthalpy);
                end
            end
        end
    end
end

