classdef PVCollector < handle
    %PV Summary of this class goes here
    %   Detailed explanation goes here
    
    properties
        Material % CdTe, Si, or CIGS
        Wp % Wp per m^2 module area
        %         alphaIsc
        %         a
        %         IL
        %         I0
        %         Rsh
        %         Rs
        %         Eg
        %         dEgdT
    end
    
    methods
        %         function collector = PVCollector(alphaSC, a, iL, i0, rsh, rs, eg, dEgdT)
        function collector = PVCollector(material, wp)
            if nargin == 0
                warning('Null input constructor call: PVCollector');
            elseif nargin == 2
                collector.Material = material;
                collector.Wp = wp;
                %                 collector.alphaSC = alphaSC;
                %                 collector.a = a;
                %                 collector.IL = iL;
                %                 collector.I0 = i0;
                %                 collector.Rsh = rsh;
                %                 collector.Rs = rs;
                %                 collector.Eg = eg;
                %                 collector.dEgdT = dEgdT;
            else
                error('Not correct number of inputs. Please specify 2 inputs for a PVCollector')
            end
        end
        %         function etaPV = getEfficiency(collector, G, Tcell)
        %             % G : irradiance on a defined surface as calculated from the
        %             % the function IRRADIANCECALC
        %             % Tcell : the cell temperature as calculated from the function
        %             % PVL_SAPMCELLTEMP
        %
        %             ModuleParameters = struct(a_ref, collector.a, IL_ref,...
        %                 collector.IL, I0_ref, collector.I0, Rsh_ref, collector.Rsh,...
        %                 Rs_ref, collector.Rs);
        %
        %             % Calculate the parameters under current operating conditions
        %             [IL_op, I0_op, Rs_op, Rsh_op, a_op] = pvl_calcparams_desoto(G,Tcell,collector.alphaSC,...
        %                 ModuleParameters, collector.EgRef, collector.dEgdT);
        %
        %             % Now use the operating parameters to get the power output from
        %             % the single diode model
        %             Result = pvl_singlediode(IL_op, I0_op, Rs_op, Rsh_op, a_op);
        %
        %             % Maximum power is assumed, using a maximum power point tracker
        %             etaPV = zeros(size(G));
        %             etaPV(G>0) = Result.Pmp(G>0) ./ G(G>0);
        %
        %         end
        
        
        function etaPV = getEfficiency(collector, G, Ta)
            % The sandia emperical PV model (King, 2005) is used with
            % coefficients from (Huld, 2010)
            
            Tstc = 25; % temperature at standard condition for Wpeak messurments C
            Gstc = 1000; % irradiance at standard condition for Wpeak messurments W/m^2
            
            %             PWp = 1; % Installed Wp solar power (gammal 1422600)
%             CSiWm2 = 150;
%             CdTeWm2 = 100;
            
            %Inputdata for solar irradiance
            %temp_data=randn(231,181,length(NCFiles))+3; %Inputdata for ambient temperature%25;%
            
            Tmod = Ta+0.035.*G; % PV module temperature
            Tekv = Tmod-Tstc;  % Temperature equation
            Gekv = G./Gstc;  % Irradiance equation
            
            index = Gekv > 0;
            
            switch collector.Material
                case 'Si'
                    coef = [-0.017162, -0.040289, -0.004681, 0.000148, 0.000169, 0.000005]; % coefficients for cSi panels
%                     coef=[-0.01724 -0.04047 -0.0047 0.000149 0.000147 0.000005 ];  %coefficients for cSi and CIS panels
                    
                case 'CdTe'
                    coef = [-0.103251, -0.040446, -0.001667, -0.002075, -0.001445, -0.000023];  % coefficients for Cd_Te panels
                    
                case 'CIGS'
                    coef = [-0.005521, -0.038492, -0.003701, -0.000899, -0.001248, 0.000001]; % coefficients for CIGS/CIS panels
                    
%                     PCdTe=zeros(size(G,1),size(G,2),size(G,3));
%                     PCdTe(index) =Gekv(index).*(1 + CdTeCoef(1).*log(Gekv(index)) + CdTeCoef(2).*log(Gekv(index)).^2 + CdTeCoef(3).*Tekv(index) + CdTeCoef(4).*Tekv(index).*log(Gekv(index)) + CdTeCoef(5).*Tekv(index).*log(Gekv(index)).^2 + CdTeCoef(6).*Tekv(index).^2);
%                     PCdTe( isnan(PCdTe) == 1 | PCdTe < 0 ) = 0;

                otherwise
                    errordlg('The selected PV material type is not recognized')
            end
            
            P=zeros(size(G,1),size(G,2),size(G,3));
            P(index)=Gekv(index).*(1 + coef(1).*log(Gekv(index)) + coef(2).*log(Gekv(index)).^2 + coef(3).*Tekv(index) + coef(4).*Tekv(index).*log(Gekv(index)) + coef(5).*Tekv(index).*log(Gekv(index)).^2 + coef(6).*Tekv(index).^2);
            P( isnan(P) == 1 | P < 0 ) = 0;
            PVpower = P .* collector.Wp;
            etaPV = zeros(size(G));
            etaPV(G>0) = PVpower(G>0) ./ G(G>0);
        end
        %         function [PVenergy, Ib, Id, Ig] = getEnergy(collector, GdirectNormal, GglobalHorizontal, GdiffuseHorizontal, GetrNormal, GetrHorizontal, albedo, Ta, sunZenith, sunAzimuth, panelInclination)
        %             if nargin == 11
        %                 % Assume collector faces due South
        %                 panelDirection = 0;
        % %                 panelInclination=panelInclination-2;
        % %                 panelInclination(panelInclination<0)=0;
        %
        % %                 % Emil code
        % %                 [irradianceEmil , IbE, IdE, IgE] = collector.irradianceCalc(GdirectNormal, GdiffuseHorizontal, GetrHorizontal, albedo, sunZenith, sunAzimuth, panelInclination, panelDirection);
        % %                 PVenergyEmil = collector.PVcalc(irradianceEmil, Ta);
        % %                 PVenergy = PVenergyEmil;
        % %                 Ib = IbE;
        % %                 Id = IdE;
        % %                 Ig = IgE;
        %
        %                 % Pepe code
        % %                 incAngle = collector.incangles(sunAzimuth, sunZenith, panelDirection, panelInclination);
        % %                 [irradiancePepe, IbP, IdP, IgP] = collector.irradianceCalcPepe(GdirectNormal, GglobalHorizontal, GdiffuseHorizontal, GetrNormal, albedo, incAngle, sunZenith, panelInclination);
        %                 PVenergy = collector.PVcalc(irradiancePepe, Ta);
        % %                 Ib = IbP;
        % %                 Id = IdP;
        % %                 Ig = IgP;
        %
        % %                 PVenergy = PVenergyEmil - PVenergyPepe;
        % %                 Ib = IbE - IbP;
        % %                 Id = IdE - IdP;
        % %                 Ig = IgE - IgP;
        %             else
        %                 error('Please specify 11 inputs to the PVCollector.getEnergy function')
        %             end
        %         end
    end
    
    methods (Access = private)
        %         incDirect = incangles(collector, sunAzimuth, sunZenith, panelDirection, panelInclination);
        %         [irradianceEmil , Ib, Id, Ig] = irradianceCalc(collector, GdirectNormal, GdiffuseHorizontal, GetrHorizontal, albedo, sunZenith, sunAzimuth, panelInclination, panelDirection);
        %             PVenergy = PVcalc(collector, irradiance, Ta);
    end
    
end


    
    
    
    
 
