% Insolation on a tilted surface for one fixed orientation
% Tilt equation taken from Hay(diffuse) with incoreperation of panel direction
% from Iqbal.


% The output of the function will give you IRRADIANCE on the defined
% surface (defined by panel_direction and panel_inclination)
function [irr_data_tilted, irr_data_tilted_beam, irr_data_tilted_diff, ground_reflection_irr]= irradianceCalc(~, direct_normal, irr_data_diffuse, sol_I_O, albedo, sol_zenit, sol_azi, panel_inclination, panel_direction)
% direct_normal = Direct normal IRRADIANCE, In the TMY file it is called "directnormal"
% irr_data_diffuse = Diffuse horizontal IRRADIANCE,  In the TMY file it is called "diffusehorizontal"
% sol_zenit = Solar zenit angle, called "zenith"
% sol_azi = Solar azimuth angle, called "azimuth"
% sol_I_O = extraterrestrial IRRADIANCE on a horizontal surface, called "ETRhorizontal"
% albedo = Albedo of the ground, called "albedocorrected"
% panel_direction = Direction of the solar panel in east-west direction (negative indicating eastward direction)
% panel_inclination = inclination of PV panel with zero degrees being horizontal
% Preperation of values

sol_alt=90-sol_zenit;






% Coefficients for reflection losses King, D.L. et al., Field experience with a new performance
%characterization procedure for photovoltaic arrays, 2nd World Conference
%and Exhibition on Photovoltaic Solar Energy Conversion, 1998.

ang_coef = [1 -2.44*10^(-3) 3.10*10^(-4) -1.25*10^(-5) 2.11*10^(-7) -1.36*10^(-9)];

% Preperation step inorder to remove all values that are below the sun horizon i.e. a negative sol_alt value

% Clean up any irradiance data less than zero, as that is impossible.
direct_normal(direct_normal < 0) = 0;
irr_data_diffuse(irr_data_diffuse < 0) = 0;
sol_I_O(sol_I_O < 0) = 0;




% 
% index_for_zero= sol_alt <= 0;
% 
% irr_data_tilted(index_for_zero) = 0;

index_rest = sol_alt > 0;

horizontal_direct_irr = zeros (size(irr_data_diffuse,1),size(irr_data_diffuse,2),size(irr_data_diffuse,3));
horizontal_direct_irr(index_rest)=direct_normal(index_rest).*sind(sol_alt(index_rest));

irr_data_global_inter = zeros (size(irr_data_diffuse,1),size(irr_data_diffuse,2),size(irr_data_diffuse,3));
irr_data_global_inter(index_rest) = horizontal_direct_irr(index_rest)+irr_data_diffuse(index_rest);

% The global horizontal irridation should not be greater then the
% extraterrestrial on a horizontal surface
ind = sol_I_O < irr_data_global_inter;

irr_data_diffuse(ind)=0;
% Calculation of angle of incidence


ang_of_ind = zeros (size(irr_data_diffuse,1),size(irr_data_diffuse,2),size(irr_data_diffuse,3));
ang_of_ind(index_rest) = acosd(cosd(panel_inclination).*sind(sol_alt(index_rest))+sind(panel_inclination).*cosd(sol_alt(index_rest)).*cosd(sol_azi(index_rest)-panel_direction)); 


ind_ang_mod = zeros (size(irr_data_diffuse,1),size(irr_data_diffuse,2),size(irr_data_diffuse,3));
ind_ang_mod(index_rest) = ang_coef(1) + ang_coef(2).*ang_of_ind(index_rest) + ang_coef(3).*ang_of_ind(index_rest).^2 + ang_coef(4).*ang_of_ind(index_rest).^3 + ang_coef(5).*ang_of_ind(index_rest).^4 + ang_coef(6).*ang_of_ind(index_rest).^5;
ind_ang_mod(ang_of_ind>=90)=0;

%The above calculation with Coefficients for reflection losses can result
%in very small negative values at angle of incidences close to 90, ind_ang_mod is
%set to zero in such cases
ind_ang_mod(ind_ang_mod<0)=0;


% Beam component of irradiance

% The anisotropy index (Ai) "determines the portion of the horizontal diffuse
% radiation which is to be treated as forward scattered"
% Avoid dividing by zero.
indetr = sol_I_O > 0;




irr_data_tilted_beam = zeros (size(irr_data_diffuse,1),size(irr_data_diffuse,2),size(irr_data_diffuse,3));
Rb =zeros(size(irr_data_diffuse,1),size(irr_data_diffuse,2),size(irr_data_diffuse,3));
Rb(index_rest)=(cosd(panel_inclination).*sind(sol_alt(index_rest))+sind(panel_inclination).*cosd(sol_alt(index_rest)).*cosd(sol_azi(index_rest)-panel_direction))./sind(sol_alt(index_rest));
Ai= zeros(size(irr_data_diffuse,1),size(irr_data_diffuse,2),size(irr_data_diffuse,3));
Ai(indetr) = ((horizontal_direct_irr(indetr))./sol_I_O(indetr));

% Ai should never be greater than 1, so remove all erroneous values: These
% must be data errors. Also sets all Rb where angle of incidence is greater
% then 90
Ai(Ai > 1) = 0;
Rb(ang_of_ind>90) = 0;

irr_data_tilted_beam(index_rest) = ind_ang_mod(index_rest).*(( horizontal_direct_irr(index_rest)).*Rb(index_rest))+ irr_data_diffuse(index_rest).*(ind_ang_mod(index_rest).*Ai(index_rest).*Rb(index_rest));
 



% Diffuse component of irradiance

ang_of_ind_diff = zeros (size(irr_data_diffuse,1),size(irr_data_diffuse,2),size(irr_data_diffuse,3));
ang_of_ind_diff(index_rest) = 59.7-0.1388.*(panel_inclination)+0.001497.*(panel_inclination).^2;

ind_ang_mod_diff = zeros (size(irr_data_diffuse,1),size(irr_data_diffuse,2),size(irr_data_diffuse,3));

ind_ang_mod_diff(index_rest) =ang_coef(1) + ang_coef(2).*ang_of_ind_diff(index_rest) + ang_coef(3).*ang_of_ind_diff(index_rest).^2 + ang_coef(4).*ang_of_ind_diff(index_rest).^3 + ang_coef(5).*ang_of_ind_diff(index_rest).^4 + ang_coef(6).*ang_of_ind_diff(index_rest).^5;

%clear ang_of_ind_diff

irr_data_tilted_diff = zeros (size(irr_data_diffuse,1),size(irr_data_diffuse,2),size(irr_data_diffuse,3));

irr_data_tilted_diff(index_rest) = irr_data_diffuse(index_rest).*(ind_ang_mod_diff(index_rest).*(1-Ai(index_rest)).*((1+cosd(panel_inclination))/2));
    
%clear ind_ang_mod_diff
%clear ind_ang_mod


% Ground reflection component of irradiance

ang_of_ind_ground = zeros (size(irr_data_diffuse,1),size(irr_data_diffuse,2),size(irr_data_diffuse,3));
ang_of_ind_ground(index_rest) = 90-0.5788.*(panel_inclination)+0.002693.*(panel_inclination).^2;



ind_ang_mod_ground = zeros (size(irr_data_diffuse,1),size(irr_data_diffuse,2),size(irr_data_diffuse,3));
ind_ang_mod_ground(index_rest) =ang_coef(1) + ang_coef(2).*ang_of_ind_ground(index_rest) + ang_coef(3).*ang_of_ind_ground(index_rest).^2 + ang_coef(4).*ang_of_ind_ground(index_rest).^3 + ang_coef(5).*ang_of_ind_ground(index_rest).^4 + ang_coef(6).*ang_of_ind_ground(index_rest).^5;

%clear ang_of_ind_ground

ground_reflection_irr = zeros (size(irr_data_diffuse,1),size(irr_data_diffuse,2),size(irr_data_diffuse,3));
ground_reflection_irr(index_rest) =ind_ang_mod_ground(index_rest).* albedo(index_rest).*irr_data_global_inter(index_rest).*((1-cosd(panel_inclination))./2);
 
 %marker=1;
%clear ind_ang_mod_ground
%
irr_data_tilted = zeros (size(irr_data_diffuse,1),size(irr_data_diffuse,2),size(irr_data_diffuse,3));  %Matrix for output of irradation data for tilited surface
irr_data_tilted(index_rest) = ground_reflection_irr(index_rest)+irr_data_tilted_diff(index_rest)+irr_data_tilted_beam(index_rest);


%Error checking
if any(irr_data_tilted > 2000)
    %error('Data error:  calculated total radiation is greater than 2000 W/m^2')
    keyboard
end
if  any(ground_reflection_irr < 0) || any(irr_data_tilted_diff < 0)|| any(irr_data_tilted_beam < 0)
    %error('Data error:  Some component of calculated irradiance is less than zero')
    keyboard
end
 % 



end


% clear ground_reflection_irr 
% clear irr_data_tilted_diff 
% clear irr_data_tilted_beam
%                         
% index_remove_neg = irr_data_tilted < 0;
% 
% 
% irr_data_tilted(index_remove_neg)=0;  %Removes any irridation values that are negative
% 
% %% Removal of devil-finger artifacts 
% % Might not be needed with TMY data. This was done to handel issues that
% % arose due ti interploation of previous data.
% %
% 
% for i = 1:size(irr_data_diffuse,1)
%     
%     for p = 1:size(irr_data_diffuse,2)
%         
%         for r = 2:(size(irr_data_diffuse,3)-1)
%     
%          if irr_data_tilted(i,p,r-1) == 0 && irr_data_tilted(i,p,r+1) < irr_data_tilted(i,p,r)
%              
%              irr_data_tilted(i,p,r) = irr_data_tilted(i,p,r+1)/2;
%          end
%          
%          if irr_data_tilted(i,p,r+1) == 0 && irr_data_tilted(i,p,r-1) < irr_data_tilted(i,p,r)
%              
%              irr_data_tilted(i,p,r) = irr_data_tilted(i,p,r-1)/2;
%          end
%              
%          
%         end
%     end
% end
% 
% 
% 
% 
%  irr_data_tilted.irr_data_tilted=irr_data_tilted;
%  irr_data_tilted.ground_reflection_irr=ground_reflection_irr;
%  irr_data_tilted.irr_data_tilted_diff=irr_data_tilted_diff;
%  irr_data_tilted.irr_data_tilted_beam=irr_data_tilted_beam;
%  irr_data_tilted.horizontal_direct_irr=horizontal_direct_irr;
%  irr_data_tilted.ind_ang_mod=ind_ang_mod;
%  irr_data_tilted.ang_of_ind=ang_of_ind;