classdef PVSystem < System
    
    properties
        Collector
        Inverter
        TrackingAxes
        WpEl % system Wp per m^2 collector
    end
    
    methods
        function sys = PVSystem(collector, inverter, trackingAxes)
            if nargin == 0
                warning('Null input constructor call: PVSystem');
            elseif nargin == 3
                if ~isa(collector,'PVCollector') && ~isa(collector,'CPVCollector')
                    error('Please specify a PVCollector or CPVCollector object as the 1st input')
                else
                    sys.Collector = collector;
                end
                
                if ~isa(inverter,'Inverter')
                    error('Please specify an Inverter object as the 3rd input')
                else
                    sys.Inverter = inverter;
                end
                
                if ~((trackingAxes>=0)&&(trackingAxes<=2))
                    error('Please specify the number of tracking axes between 0 (no-tracking) and 2 (2-axis tracking) as the 3rd input')
                else
                    sys.TrackingAxes = trackingAxes;
                end
                
                % Calculate system rated power as collector rated power
                % times inverter efficiency.
                sys.WpEl = sys.Collector.Wp*sys.Inverter.Eta;
            else
                error('Not correct number of inputs. Please specify 3 inputs for a PVSystem')
            end
            
        end %end constructor
        
    end % end methods block
    
    methods (Access = public)
    end
end