classdef PVTCollector < HeatExchanger
    %PVTCOLLECTOR Summary of this class goes here
    %   Detailed explanation goes here
    
    properties
        % Should add a Wp property for PVT collector
        StateIn
        StateOut
        ConcentrationFactor
    end
    
    methods
        function PVTCollector = PVTCollector(concentrationFactor)
            if nargin == 0
                warning('Null input constructor call: PVTCollector');
            elseif nargin == 1
                PVTCollector.ConcentrationFactor = concentrationFactor;
                PVTCollector.StateIn = [];
                PVTCollector.StateOut = [];
            else
                error('Not correct number of inputs. Please specify 1 input, a concentration factor')
            end
        end
        
        function heatOut = getHeat(PVTcollector, stateIn, temperatureOut)
            if nargin ~= 3
                error('Please specify 3 inputs to the ThermalCollector.calculate function')
            end
            PVTcollector.StateIn = stateIn;
            PVTcollector.StateOut = FluidState(PVTcollector.StateIn.FluidModel, 'pressure', PVTcollector.StateIn.Pressure,'temperature', temperatureOut);
            heatOut = (PVTcollector.StateOut.Enthalpy - PVTcollector.StateIn.Enthalpy);
        end
        
        function [etaThermal, etaPV] = getEfficiency(PVTCollector, G, Ta)
            if isempty(PVTCollector.StateIn) || isempty(PVTCollector.StateOut)
                error('Efficiency cannot be calculated until both input and output states have been specified.')
            elseif nargin == 3
                etaThermal = zeros(size(G));
                etaPV = zeros(size(G));
                for i=1:length(G)
                    [etaThermal(i), etaPV(i)] = PVTCollector.PVTcalc(Ta(i), PVTCollector.StateIn.Temperature, PVTCollector.StateOut.Temperature, PVTCollector.ConcentrationFactor, G(i));
                end
            else
                error('Please specify 3 inputs to the HybridPVT.getEfficiency function')
            end
        end
        
        
    end
    methods (Access = private)
        [etaThermal, etaPV] = PVTcalc(PVTCollector, Ta, Tin, Tout, C, G);
    end
    
end

