classdef Pump < TurboMachine
    %Pump a default pump object
    %   Pump calculates the pump work to go from state in to the system
    %   high pressure.
    
    methods
        function pump = Pump(eta)
            %             if nargin == 3
            %                 pump.Eta = eta;
            %                 pump.calculate(stateIn, pressureOut)
            %             elseif nargin > 3
            %                 error('Too many inputs. Please specify 3 inputs; an input state, an output Pressure, and an efficiency')
            %             elseif nargin > 0
            %                 error('Not enough inputs. Please specify an input state, an output Pressure, and an efficiency')
            %             else % nargin = 0, create default pump object
            %                 pump.StateIn = [];
            %                 pump.StateOut = [];
            %             end
            if nargin == 1
                pump.Eta = eta;
                pump.StateIn = [];
                pump.StateOut = [];
            elseif nargin > 1
                error('Too many inputs. Please specify 1 input, an efficiency')
            else
                error('Not enough inputs. Please specify 1 input, an efficiency')
            end
        end
        
        function pumpWork = getWork(pump,stateIn,pressureOut)
            if nargin ~= 3
                error('Please specify 3 inputs to the pump.calculate function')
                %                 disp(['No pump efficiency specified, using default of ' num2str(Pump.getDefaultEta)])
                %                 pump.Eta = Pump.getDefaultEta;
            end
            pump.StateIn = stateIn;
            %             Ws = pump.StateIn.Volume * (pressureOut - pump.StateIn.Pressure);
            %             W = Ws / eta;
            
            stateOutS = FluidState(pump.StateIn.FluidModel, 'entropy', pump.StateIn.Entropy, 'pressure', pressureOut);
            enthalpyOut = (stateOutS.Enthalpy - pump.StateIn.Enthalpy) / pump.Eta + pump.StateIn.Enthalpy;
            pump.StateOut = FluidState(pump.StateIn.FluidModel, 'enthalpy', enthalpyOut, 'pressure', pressureOut);
            pumpWork = (pump.StateOut.Enthalpy - pump.StateIn.Enthalpy);
            
        end
        
        function eta = getIsentropicEfficiency(pump)
            stateOutS = FluidState(pump.StateIn.FluidModel, 'entropy', pump.StateIn.Entropy, 'pressure', pump.StateOut.Pressure);
            eta = (stateOutS.Enthalpy - pump.StateIn.Enthalpy) / (pump.StateOut.Enthalpy - pump.StateIn.Enthalpy);
        end
    end
    methods (Static)
        %used to populate the efficiency edit boxes of the gui
        function eta = getDefaultEta()
            eta = 0.90;
        end
    end
end

