function PlotTestSunData(site, sitenum, day)

% Plots all the TMY radiation data for a given site, as well as a scaled-up
% measure of sun altitude (90 deg minus zenith): if the calculations are
% correct, the zenith should peak at the same time as extraterrestrial
% horizontal radiation (ETRH).
%
% UNITS
% Structure of sites, site number (1 to 1020), and day number (1 to 365).
%
% VECTORIZATION
% Inputs should not be vectors.

% Determine data range to plot (23 hours starting at 1a and ending at 11p)
a = day*24 + 1;
b = a + 22;
% X axis is time in hours
x = site(sitenum).time.hour(a:b,1);
% Raw radiation data
y(:,1) = site(sitenum).data.ETRhorizontal(a:b,1);
y(:,2) = site(sitenum).data.ETRnormal(a:b,1);
y(:,3) = site(sitenum).data.globalhorizontal(a:b,1);
y(:,4) = site(sitenum).data.directnormal(a:b,1);
y(:,5) = site(sitenum).data.diffusehorizontal(a:b,1);
% Scaled sun position to correlate with ETRh peak
y(:,6) = (90 - site(sitenum).sun.zenith(a:b,1))*15;
%y(:,6) = site(sitenum).sun.azimuth(a:b,1);

% Plot on graph with 1 y axis:
% Clear any previous figure
clf
% Set axes and border
axes1 = axes(...
    'YTick',[0 500 1000 1500],...
    'XTick',[0 6 12 18 24],...
    'YGrid','on',...
    'XGrid','off',...
    'xlim',[0,24],...
    'ylim',[0,1500]);
box('on');
% Retain axes while plotting and adding legend
hold('all');
% Plot data
plot1 = plot(x,y);
% Set name and properties of each curve
set(plot1(1),'DisplayName','ETR h');
set(plot1(2),'DisplayName','ETR n');
set(plot1(3),'DisplayName','global h');
set(plot1(4),'DisplayName','direct n');
set(plot1(5),'DisplayName','diffuse h');
set(plot1(6),'DisplayName','sun pos','LineStyle',':');
% Display legend
legend1 = legend(axes1,'show');
set(legend1,'Location','NorthWest');
% Title and Axis Labels
xlabel({'Hour'});
ylabel('Radiation {\itW}/{\itm}^2');
titletext = [num2str(site(sitenum).info.name) ...
    ' ' num2str(site(sitenum).info.state) ...
    ', Day ' num2str(day)];
title(titletext);