function gui(sim)


sim.Figure = figure('Name','Distributed solar systems simulation');
% Set position and disable resize.  Resize is disallowed because the system
% panels are not positioned according to relative size.  This could be
% fixed in the future by changing the system panels to use relative
% indexing like the simPanel currently uses.
set(sim.Figure,'Position',[25,25,750,550],'Resize','off');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%The Simulation Panel (simPanel) will be the first thing to show when
%the gui is started. It will have compare buttons and stuff, but first
%it only has a 'Add System' button which will bring up the system gui.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

simPanel = uipanel('Parent',sim.Figure,'Position',[0,0,1,1]);

% title =
uicontrol('parent',simPanel,...
    'Style','text',...
    'Units','normalized',...
    'String','Current Systems and Environments in Simulation',...
    'Position',[.3 .93 .4 .05],...
    'FontSize', 10,...
    'HorizontalAlignment','center');

sysList = uicontrol('Parent',simPanel,'Style','listbox',...
    'Units','normalized',...
    'Min',1,...
    'Max',999999,...
    'Enable','on',...
    'String',sim.SystemNames,...
    'Position',[.1 .2 .45 .6],...
    'Callback', {@disablePlot_callback});
envList = uicontrol('Parent',simPanel,'Style','listbox',...
    'Units','normalized',...
    'Min',1,...
    'Max',999999,...
    'Enable','on',...
    'String',sim.EnvNames,...
    'Position',[.60 .2 .3 .6],...
    'Callback', {@disablePlot_callback});
uicontrol(simPanel,'Style','pushbutton',...
    'String','Add Thermal System',...
    'Units','normalized',...
    'Position',[.10,.88,.15,.05],...
    'Callback',{@addThermalSys_callback});
% addCHPSys =
uicontrol(simPanel,'Style','pushbutton',...
    'String','Add CHP System',...
    'Units','normalized',...
    'Position',[.25,.88,.15,.05],...
    'Callback',{@addCHPSys_callback});
% addPVSys =
uicontrol(simPanel,'Style','pushbutton',...
    'String','Add PV System',...
    'Units','normalized',...
    'Position',[.10,.83,.15,.05],...
    'Callback',{@addPVSys_callback});
uicontrol(simPanel,'Style','pushbutton',...
    'String','Add Hybrid PVT System',...
    'Units','normalized',...
    'Position',[.25,.83,.15,.05],...
    'Callback',{@addPVTSys_callback});
% output to GDX files (for ELIN)
outputSitesGDX = uicontrol(simPanel,'Style','checkbox',...
    'String','output production profiles, sites data, and technology info and costs (*.gdx for ELIN)',...
    'Units','normalized',...
    'Position',[.4,.06,.6,.03]);
outputTechGDX = uicontrol(simPanel,'Style','checkbox',...
    'String','output only technology info and costs (*.gdx for ELIN)',...
    'Units','normalized',...
    'Position',[.4,.03,.6,.03]);
calculate = uicontrol('Parent',simPanel,...
    'Style','pushbutton',...
    'String','Calculate',...
    'Units','normalized',...
    'Position',[.4,.1,.10,.05],...
    'Callback',{@calculate_callback});
plotButton = uicontrol('Parent',simPanel,...
    'Style','pushbutton',...
    'String','Plot',...
    'units','normalized',...
    'Position',[.5,.1,.10,.05],...
    'Callback',{@plotButton_callback},...
    'Enable', 'off');
compare = uicontrol('Parent',simPanel,...
    'Style','pushbutton',...
    'String','Compare',...
    'units','normalized',...
    'Position',[.6,.1,.10,.05],...
    'Callback',{@compare_callback},...
    'Enable', 'off');
importEnvUS = uicontrol('Parent',simPanel,...
    'Style','pushbutton',...
    'String',' Import US Environments',...
    'units','normalized',...
    'Position',[.60, .85, .15, .05],...
    'Callback',{@importEnvUS_callback});
importEnvEUR = uicontrol('Parent',simPanel,...
    'Style','pushbutton',...
    'String',' Import Europe Environments',...
    'units','normalized',...
    'Position',[.75, .85, .15, .05],...
    'Callback',{@importEnvEUR_callback});
% if length(sim.EnvArray) > 1000
%     set(importEnv,'Enable','off')
% end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%The ThermalsysPanel is brought up when the 'addThermalSys' button is pushed. It contains
%the gui for building a hybrid PVT system.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%This panel is invisible until 'addThermalSys'
thermalSysPanel = uipanel('Parent',sim.Figure,'Position',[0,0,1,1], 'visible', 'off');

% System Name %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
nameThermal = uicontrol('Parent',thermalSysPanel,'Style','text',...
    'Position',[350 517 150 20],...
    'String',['System ' num2str(length(sim.SystemArray)+1)]);
% % nameText =
% uicontrol('Parent',thermalSysPanel,'Style','text',...
%     'Position',[250 517 90 20],...
%     'String','System Name:',...
%     'HorizontalAlignment','right');

% build system button %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% build =
uicontrol(thermalSysPanel,'Style','pushbutton',...
    'String','Save & Add System',...
    'Units','normalized',...
    'Position',[.8,.05,.18,.05],...
    'Callback',{@buildThermal_callback});
% cancel =
uicontrol(thermalSysPanel,'Style','pushbutton',...
    'String','Cancel',...
    'Units','normalized',...
    'Position',[.8 .12 .18 .05],...
    'Callback',{@cancel_callback});

%Load the image of a Thermal system %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

imaxes = axes('Parent',thermalSysPanel,'units','normalized',...
    'Position',[.02 .02 .96 .9]);
im = imread('Thermal system schematic.png');
image([1 2557],[1 1659],im,'Parent',imaxes);
axis off
axis image
set(sim.Figure,'Position',[25,25,750,550]);



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Component configuration input boxes for Thermal System
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% working fluid %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fluidThermalSelect = uicontrol('Parent',thermalSysPanel,'Style','popupmenu',...
    'String',{'water','Placeholder 1','Placeholder 2'},...
    'Position',[350,490,120,20]);
% fluidText =
uicontrol('Parent',thermalSysPanel,'Style','text',...
    'Position',[250 487 90 20],...
    'String','Working Fluid:',...
    'HorizontalAlignment','right');

% Fluid heat exchanger %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
hxThermalSelect = uicontrol('Parent',thermalSysPanel','Style','popupmenu',...
    'String',{'Fluid heat exchanger','Placeholder 1','Placeholder 2'},...
    'Position',[520,125,120,20]);
hxThermalEtaEdit = uicontrol('Parent',thermalSysPanel,'Style','edit',...
    'TooltipString','Enter the condenser efficiency',...
    'String',num2str(FluidHX.getDefaultEta),...
    'Position',[582,105,40,20]);
% condEtaText =
uicontrol('Parent',thermalSysPanel,'Style','text',...
    'String','Efficiency:',...
    'Position',[520,102,52,20],'HorizontalAlignment','right');


% pump %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
pumpThermalSelect = uicontrol('Parent',thermalSysPanel,'Style','popupmenu',...
    'String',{'Pump','Placeholder 1','Placeholder 2'},...
    'Position',[60,105,120,20]);
pumpThermalEtaEdit = uicontrol('Parent',thermalSysPanel,'Style','edit',...
    'TooltipString','Enter the pump efficiency',...
    'String',num2str(Pump.getDefaultEta),...
    'Position',[122,85,40,20]);
% pumpEtaText =
uicontrol('Parent',thermalSysPanel,'Style','text',...
    'String','Efficiency:',...
    'Position',[60,82,52,20],'HorizontalAlignment','right');

% collector %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
colecThermalSelect = uicontrol('Parent',thermalSysPanel,'Style','popupmenu',...
    'String',{'Flat-plate','Evacuated tube','Concentrating trough'},...
    'Position',[15,275,120,20]);
colecThermalTrackingEdit = uicontrol('Parent',thermalSysPanel,'Style','edit',...
    'TooltipString','Enter the tracking dimension',...
    'Position',[77,255,40,20]);
%     'String',num2str(ThermalCollector.getDefaultEta),...

% colecEtaText =
% uicontrol('Parent',thermalSysPanel,'Style','text',...
%     'String','Efficiency:',...
%     'Position',[15,252,52,20],'HorizontalAlignment','right');

% colecThermalTrackingText =
uicontrol('Parent',thermalSysPanel,'Style','text',...
    'String','Tracking dimension:',...
    'Position',[15,242,60,30],'HorizontalAlignment','right');


% outlet temperature from collector %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% temperature input %
highTempThermalEdit = uicontrol('Parent',thermalSysPanel,'Style','edit',...
    'TooltipString','Enter collector output temperature in Kelvin',...
    'Position',[375,375,40,20]);

% tempText =
uicontrol('Parent',thermalSysPanel,'Style','text',...
    'String','Temperature:',...
    'Position',[305,372,65,20],'HorizontalAlignment','right');
% tempUnits =
uicontrol('Parent',thermalSysPanel,'Style','text',...
    'String','[K]',...
    'Position',[420,372,30,20],'HorizontalAlignment','left');

% outlet temperature from heat exchanger %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% temperature input %
lowTempThermalEdit = uicontrol('Parent',thermalSysPanel,'Style','edit',...
    'TooltipString','Enter heat exchanger outlet temperature in Kelvin',...
    'Position',[300,190,40,20]);

% tempText =
uicontrol('Parent',thermalSysPanel,'Style','text',...
    'String','Temperature:',...
    'Position',[230,187,65,20],'HorizontalAlignment','right');
% tempUnits =
uicontrol('Parent',thermalSysPanel,'Style','text',...
    'String','[K]',...
    'Position',[345,187,30,20],'HorizontalAlignment','left');

% outlet pressure from heat exchanger %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% pressure exit input %
lowPressThermalEdit = uicontrol('Parent',thermalSysPanel,'Style','edit',...
    'TooltipString','Enter collector exit pressure in bars',...
    'Position',[300,170,40,20]);
% lowPressThermalText =
uicontrol('Parent',thermalSysPanel,'Style','text',...
    'String','Pressure:',...
    'Position',[245,167,50,20],'HorizontalAlignment','right');
% lowPressThermalUnits =
uicontrol('Parent',thermalSysPanel,'Style','text',...
    'String','[kPa]',...
    'Position',[345,167,50,20],'HorizontalAlignment','left');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%The CHPsysPanel is brought up when the 'addCHPSys' button is pushed. It contains
%the gui for building a rankine cycle.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%This panel is invisible until 'addCHPSys'
CHPsysPanel = uipanel('Parent',sim.Figure,'Position',[0,0,1,1], 'visible', 'off');

% System Name %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
nameCHP = uicontrol('Parent',CHPsysPanel,'Style','text',...
    'Position',[350 517 150 20],...
    'String',['System ' num2str(length(sim.SystemArray)+1)]);
% % nameText =
% uicontrol('Parent',CHPsysPanel,'Style','text',...
%     'Position',[250 517 90 20],...
%     'String','System Name:',...
%     'HorizontalAlignment','right');

% build system button %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% build =
uicontrol(CHPsysPanel,'Style','pushbutton',...
    'String','Save & Add System',...
    'Units','normalized',...
    'Position',[.8,.05,.18,.05],...
    'Callback',{@buildCHP_callback});
% cancel =
uicontrol(CHPsysPanel,'Style','pushbutton',...
    'String','Cancel',...
    'Units','normalized',...
    'Position',[.8 .12 .18 .05],...
    'Callback',{@cancel_callback});

%Load the image of a CHP system%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
imaxes = axes('Parent',CHPsysPanel,'units','normalized',...
    'Position',[.02 .02 .96 .9]);
im = imread('CHP system schematic.png');
image([1 2557],[1 1659],im,'Parent',imaxes);
axis off
axis image
set(sim.Figure,'Position',[25,25,750,550]);



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Component configuration input boxes for CHP System
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% working fluid %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fluidCHPSelect = uicontrol('Parent',CHPsysPanel,'Style','popupmenu',...
    'String',{'water','Placeholder 1','Placeholder 2'},...
    'Position',[350,490,120,20]);
% fluidText =
uicontrol('Parent',CHPsysPanel,'Style','text',...
    'Position',[250 487 90 20],...
    'String','Working Fluid:',...
    'HorizontalAlignment','right');


% expander %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
expanderCHPSelect = uicontrol('Parent',CHPsysPanel,'Style','popupmenu',...
    'String',{'Expander','Placeholder 1','Placeholder 2'},...
    'Position',[450,335,120,20]);
expanderCHPEtaEdit = uicontrol('Parent',CHPsysPanel,'Style','edit',...
    'TooltipString','Enter the expander efficiency',...
    'String',num2str(Expander.getDefaultEta),...
    'Position',[507,315,40,20]);
% expanderCHPEtaText =
uicontrol('Parent',CHPsysPanel,'Style','text',...
    'String','Efficiency:',...
    'Position',[450,312,52,20],'HorizontalAlignment','right');


% generator %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
genCHPSelect = uicontrol('Parent',CHPsysPanel,'Style','popupmenu',...
    'String',{'Generator','Placeholder 1','Placeholder 2'},...
    'Position',[600,335,120,20]);
genCHPEtaEdit = uicontrol('Parent',CHPsysPanel,'Style','edit',...
    'TooltipString','Enter the generator efficiency',...
    'String',num2str(Generator.getDefaultEta),...
    'Position',[657,315,40,20]);
% genCHPEtaText =
uicontrol('Parent',CHPsysPanel,'Style','text',...
    'String','Efficiency:',...
    'Position',[600,312,52,20],'HorizontalAlignment','right');

% condenser %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
condCHPSelect = uicontrol('Parent',CHPsysPanel','Style','popupmenu',...
    'String',{'Condenser','Placeholder 1','Placeholder 2'},...
    'Position',[520,125,120,20]);
condCHPEtaEdit = uicontrol('Parent',CHPsysPanel,'Style','edit',...
    'TooltipString','Enter the condenser efficiency',...
    'String',num2str(Condenser.getDefaultEta),...
    'Position',[582,105,45,20]);
% condEtaText =
uicontrol('Parent',CHPsysPanel,'Style','text',...
    'String','Efficiency:',...
    'Position',[520,102,57,20],'HorizontalAlignment','right');


% pump %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
pumpCHPSelect = uicontrol('Parent',CHPsysPanel,'Style','popupmenu',...
    'String',{'Pump','Placeholder 1','Placeholder 2'},...
    'Position',[60,105,120,20]);
pumpCHPEtaEdit = uicontrol('Parent',CHPsysPanel,'Style','edit',...
    'TooltipString','Enter the pump efficiency',...
    'String',num2str(Pump.getDefaultEta),...
    'Position',[122,85,45,20]);
% pumpEtaText =
uicontrol('Parent',CHPsysPanel,'Style','text',...
    'String','Efficiency:',...
    'Position',[60,82,57,20],'HorizontalAlignment','right');

% collector %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
colecCHPSelect = uicontrol('Parent',CHPsysPanel,'Style','popupmenu',...
    'String',{'Evacuated tube','Concentrating trough'},...
    'Position',[15,275,120,20]);
colecCHPTrackingEdit = uicontrol('Parent',CHPsysPanel,'Style','edit',...
    'TooltipString','Enter the tracking dimension',...
    'Position',[77,255,40,20]);
% colecEtaText =
% uicontrol('Parent',CHPsysPanel,'Style','text',...
%     'String','Efficiency:',...
%     'Position',[15,252,52,20],'HorizontalAlignment','right');
% colecCHPTrackingText =
uicontrol('Parent',CHPsysPanel,'Style','text',...
    'String','Tracking dimension:',...
    'Position',[15,242,60,30],'HorizontalAlignment','right');

% inlet conditions to expander %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% temperature input %
highTempCHPEdit = uicontrol('Parent',CHPsysPanel,'Style','edit',...
    'TooltipString','Enter expander inlet temperature in Kelvin',...
    'Position',[435,385,40,20]);

% tempText =
uicontrol('Parent',CHPsysPanel,'Style','text',...
    'String','Temperature:',...
    'Position',[365,382,65,20],'HorizontalAlignment','right');
% tempUnits =
uicontrol('Parent',CHPsysPanel,'Style','text',...
    'String','[K]',...
    'Position',[480,382,30,20],'HorizontalAlignment','left');

% pressure input %
highPressCHPEdit = uicontrol('Parent',CHPsysPanel,'Style','edit',...
    'TooltipString','Enter expander inlet pressure in bars',...
    'Position',[435,365,40,20]);
% highPressCHPText =
uicontrol('Parent',CHPsysPanel,'Style','text',...
    'String','Pressure:',...
    'Position',[375,362,50,20],'HorizontalAlignment','right');
% highPressCHPUnits =
uicontrol('Parent',CHPsysPanel,'Style','text',...
    'String','[kPa]',...
    'Position',[480,362,30,20],'HorizontalAlignment','left');

% exit conditions of expander %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% pressure exit input %
lowPressCHPEdit = uicontrol('Parent',CHPsysPanel,'Style','edit',...
    'TooltipString','Enter expander exit pressure in bars',...
    'Position',[490,205,40,20]);
% lowPressCHPText =
uicontrol('Parent',CHPsysPanel,'Style','text',...
    'String','Pressure:',...
    'Position',[435,202,50,20],'HorizontalAlignment','right');
% lowPressCHPUnits =
uicontrol('Parent',CHPsysPanel,'Style','text',...
    'String','[kPa]',...
    'Position',[535,202,50,20],'HorizontalAlignment','left');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%The PVsysPanel is brought up when the 'addPVSys' button is pushed. It is
%the gui for building a PV system.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%The panel is invisible until 'addPVSys'
PVsysPanel = uipanel('Parent',sim.Figure,'Position',[0,0,1,1], 'visible', 'off');

% System Name %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
namePV = uicontrol('Parent',PVsysPanel,'Style','text',...
    'Position',[350 517 150 20],...
    'String',['System ' num2str(length(sim.SystemArray)+1)]);

% % nameText =
% uicontrol('Parent',PVsysPanel,'Style','text',...
%     'Position',[250 517 90 20],...
%     'String','System Name:',...
%     'HorizontalAlignment','right');

% build system button %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% build =
uicontrol(PVsysPanel,'Style','pushbutton',...
    'String','Save & Add System',...
    'Units','normalized',...
    'Position',[.8,.05,.18,.05],...
    'Callback',{@buildPV_callback});
% cancel =
uicontrol(PVsysPanel,'Style','pushbutton',...
    'String','Cancel',...
    'Units','normalized',...
    'Position',[.8 .12 .18 .05],...
    'Callback',{@cancel_callback});

%Load the image of a PV System%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
imaxes = axes('Parent',PVsysPanel,'units','normalized',...
    'Position',[.02 .02 .96 .9]);
im = imread('PV system schematic.png');
image([1 2557],[1 1659],im,'Parent',imaxes);
axis off
axis image
set(sim.Figure,'Position',[25,25,750,550]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Component configuration input boxes for PV System
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% collector %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
colecPVSelect = uicontrol('Parent',PVsysPanel,'Style','popupmenu',...
    'String',{'Polycrystalline-Si flat-panel PV', 'Monocrystalline-Si flat-panel PV', 'CdTe flat-panel PV', 'CIGS flat-panel PV', 'High concentration PV'},...
    'Position',[20,275,120,20]);
colecPVTrackingEdit = uicontrol('Parent',PVsysPanel,'Style','edit',...
    'TooltipString','Enter the tracking dimension',...
    'Position',[77,255,40,20]);
% colecPVTrackingText =
uicontrol('Parent',PVsysPanel,'Style','text',...
    'String','Tracking dimension:',...
    'Position',[15,242,60,30],'HorizontalAlignment','right');

% inverter %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
invPVSelect = uicontrol('Parent',PVsysPanel,'Style','popupmenu',...
    'String',{'Inverter','Placeholder 1','Placeholder 2'},...
    'Position',[340,220,120,20]);
invPVEtaEdit = uicontrol('Parent',PVsysPanel,'Style','edit',...
    'TooltipString','Enter the inverter efficiency',...
    'String',num2str(Inverter.getDefaultEta),...
    'Position',[397,200,40,20]);
% invPVEtaText =
uicontrol('Parent',PVsysPanel,'Style','text',...
    'String','Efficiency:',...
    'Position',[340,197,52,20],'HorizontalAlignment','right');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%The PVTsysPanel is brought up when the 'addPVTSys' button is pushed. It contains
%the gui for building a hybrid PVT system.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%This panel is invisible until 'addPVTSys'
PVTsysPanel = uipanel('Parent',sim.Figure,'Position',[0,0,1,1], 'visible', 'off');

% System Name %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
namePVT = uicontrol('Parent',PVTsysPanel,'Style','text',...
    'Position',[350 520 150 20],...
    'String',['System ' num2str(length(sim.SystemArray)+1)]);
% % nameText =
% uicontrol('Parent',PVTsysPanel,'Style','text',...
%     'Position',[250 517 90 20],...
%     'String','System Name:',...
%     'HorizontalAlignment','right');

% build system button %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% build =
uicontrol(PVTsysPanel,'Style','pushbutton',...
    'String','Save & Add System',...
    'Units','normalized',...
    'Position',[.8,.05,.18,.05],...
    'Callback',{@buildPVT_callback});
% cancel =
uicontrol(PVTsysPanel,'Style','pushbutton',...
    'String','Cancel',...
    'Units','normalized',...
    'Position',[.8 .12 .18 .05],...
    'Callback',{@cancel_callback});

%Load the image of a PVT system%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
imaxes = axes('Parent',PVTsysPanel,'units','normalized',...
    'Position',[.02 .02 .96 .9]);
im = imread('PVT system schematic.png');
image([1 2557],[1 1659],im,'Parent',imaxes);
axis off
axis image
set(sim.Figure,'Position',[25,25,750,550]);



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Component configuration input boxes for PVT System
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% working fluid %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fluidPVTSelect = uicontrol('Parent',PVTsysPanel,'Style','popupmenu',...
    'String',{'water','Placeholder 1','Placeholder 2'},...
    'Position',[350,490,120,20]);
% fluidText =
uicontrol('Parent',PVTsysPanel,'Style','text',...
    'Position',[250 487 90 20],...
    'String','Working Fluid:',...
    'HorizontalAlignment','right');

% inverter %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
invPVTSelect = uicontrol('Parent',PVTsysPanel,'Style','popupmenu',...
    'String',{'Inverter','Placeholder 1','Placeholder 2'},...
    'Position',[600,420,120,20]);
invPVTEtaEdit = uicontrol('Parent',PVTsysPanel,'Style','edit',...
    'TooltipString','Enter the inverter efficiency',...
    'String',num2str(Inverter.getDefaultEta),...
    'Position',[657,400,40,20]);
% invPVTEtaText =
uicontrol('Parent',PVTsysPanel,'Style','text',...
    'String','Efficiency:',...
    'Position',[600,397,52,20],'HorizontalAlignment','right');


% expander %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
expanderPVTSelect = uicontrol('Parent',PVTsysPanel,'Style','popupmenu',...
    'String',{'Expander','Placeholder 1','Placeholder 2'},...
    'Position',[450,335,120,20]);
expanderPVTEtaEdit = uicontrol('Parent',PVTsysPanel,'Style','edit',...
    'TooltipString','Enter the expander efficiency',...
    'String',num2str(Expander.getDefaultEta),...
    'Position',[507,315,40,20]);
% expanderPVTEtaText =
uicontrol('Parent',PVTsysPanel,'Style','text',...
    'String','Efficiency:',...
    'Position',[450,312,52,20],'HorizontalAlignment','right');


% generator %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
genPVTSelect = uicontrol('Parent',PVTsysPanel,'Style','popupmenu',...
    'String',{'Generator','Placeholder 1','Placeholder 2'},...
    'Position',[600,335,120,20]);
genPVTEtaEdit = uicontrol('Parent',PVTsysPanel,'Style','edit',...
    'TooltipString','Enter the generator efficiency',...
    'String',num2str(Generator.getDefaultEta),...
    'Position',[657,315,40,20]);
% genPVTEtaText =
uicontrol('Parent',PVTsysPanel,'Style','text',...
    'String','Efficiency:',...
    'Position',[600,312,52,20],'HorizontalAlignment','right');

% condenser %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
condPVTSelect = uicontrol('Parent',PVTsysPanel','Style','popupmenu',...
    'String',{'Condenser','Placeholder 1','Placeholder 2'},...
    'Position',[520,125,120,20]);
condPVTEtaEdit = uicontrol('Parent',PVTsysPanel,'Style','edit',...
    'TooltipString','Enter the condenser efficiency',...
    'String',num2str(Condenser.getDefaultEta),...
    'Position',[582,105,45,20]);
% condEtaText =
uicontrol('Parent',PVTsysPanel,'Style','text',...
    'String','Efficiency:',...
    'Position',[520,102,57,20],'HorizontalAlignment','right');


% pump %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
pumpPVTSelect = uicontrol('Parent',PVTsysPanel,'Style','popupmenu',...
    'String',{'Pump','Placeholder 1','Placeholder 2'},...
    'Position',[60,105,120,20]);
pumpPVTEtaEdit = uicontrol('Parent',PVTsysPanel,'Style','edit',...
    'TooltipString','Enter the pump efficiency',...
    'String',num2str(Pump.getDefaultEta),...
    'Position',[122,85,45,20]);
% pumpEtaText =
uicontrol('Parent',PVTsysPanel,'Style','text',...
    'String','Efficiency:',...
    'Position',[60,82,57,20],'HorizontalAlignment','right');

% collector %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
colecPVTSelect = uicontrol('Parent',PVTsysPanel,'Style','popupmenu',...
    'String',{'Concentrating hybrid PVT'},...
    'Position',[15,275,120,20]);
colecPVTTrackingEdit = uicontrol('Parent',PVTsysPanel,'Style','edit',...
    'TooltipString','Enter the tracking dimension',...
    'Position',[77,255,40,20]);
% colecPVTTrackingText =
uicontrol('Parent',PVTsysPanel,'Style','text',...
    'String','Tracking dimension:',...
    'Position',[15,242,60,30],'HorizontalAlignment','right');

% inlet conditions to expander %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% temperature input %
highTempPVTEdit = uicontrol('Parent',PVTsysPanel,'Style','edit',...
    'TooltipString','Enter expander inlet temperature in Kelvin',...
    'Position',[435,385,40,20]);

% tempText =
uicontrol('Parent',PVTsysPanel,'Style','text',...
    'String','Temperature:',...
    'Position',[365,382,65,20],'HorizontalAlignment','right');
% tempUnits =
uicontrol('Parent',PVTsysPanel,'Style','text',...
    'String','[K]',...
    'Position',[480,382,30,20],'HorizontalAlignment','left');

% pressure input %
highPressPVTEdit = uicontrol('Parent',PVTsysPanel,'Style','edit',...
    'TooltipString','Enter expander inlet pressure in bars',...
    'Position',[435,365,40,20]);
% highPressPVTText =
uicontrol('Parent',PVTsysPanel,'Style','text',...
    'String','Pressure:',...
    'Position',[375,362,50,20],'HorizontalAlignment','right');
% highPressPVTUnits =
uicontrol('Parent',PVTsysPanel,'Style','text',...
    'String','[kPa]',...
    'Position',[480,362,30,20],'HorizontalAlignment','left');

% exit conditions of expander %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% pressure exit input %
lowPressPVTEdit = uicontrol('Parent',PVTsysPanel,'Style','edit',...
    'TooltipString','Enter expander exit pressure in bars',...
    'Position',[490,205,40,20]);
% lowPressPVTText =
uicontrol('Parent',PVTsysPanel,'Style','text',...
    'String','Pressure:',...
    'Position',[435,202,50,20],'HorizontalAlignment','right');
% lowPressPVTUnits =
uicontrol('Parent',PVTsysPanel,'Style','text',...
    'String','[kPa]',...
    'Position',[535,202,50,20],'HorizontalAlignment','left');


% Callbacks %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Enables the add system panel.
    function addThermalSys_callback(~,~)
        
        set(simPanel,'visible','off');
        set(thermalSysPanel,'visible','on');
        set(nameThermal,'String',num2str(['System ' num2str(length(sim.SystemArray)+1)]));
    end

    function addCHPSys_callback(~,~)
        
        set(simPanel,'visible','off');
        set(CHPsysPanel,'visible','on');
        set(nameCHP,'String',num2str(['System ' num2str(length(sim.SystemArray)+1)]));
        %         set(fluidSelect, 'visible', 'on');
        %         set(fluidText, 'visible', 'on');
        %         set(expanderSelect, 'visible', 'on');
        %         set(expanderEtaEdit, 'visible', 'on');
        %         set(expanderEtaText, 'visible', 'on');
        %         set(genSelect, 'visible', 'on');
        %         set(genEtaEdit, 'visible', 'on');
        %         set(genEtaText, 'visible', 'on');
        %         set(condSelect, 'visible', 'on');
        %         set(condEtaEdit, 'visible', 'on');
        %         set(condEtaText, 'visible', 'on');
        %         set(pumpSelect, 'visible', 'on');
        %         set(pumpEtaEdit, 'visible', 'on');
        %         set(pumpEtaText, 'visible', 'on');
        %         set(tempEdit, 'visible', 'on');
        %         set(tempUnits, 'visible', 'on');
        %         set(tempText, 'visible', 'on');
        %         set(highPressEdit, 'visible', 'on');
        %         set(highPressUnits, 'visible', 'on');
        %         set(highPressText, 'visible', 'on');
        %         set(lowPressEdit, 'visible', 'on');
        %         set(lowPressUnits, 'visible', 'on');
        %         set(lowPressText, 'visible', 'on');
    end

    function addPVSys_callback(~,~)
        set(simPanel,'visible','off');
        set(PVsysPanel,'visible','on');
        set(namePV,'String',num2str(['System ' num2str(length(sim.SystemArray)+1)]));
    end

    function addPVTSys_callback(~,~)
        
        set(simPanel,'visible','off');
        set(PVTsysPanel,'visible','on');
        set(namePVT,'String',num2str(['System ' num2str(length(sim.SystemArray)+1)]));
    end

% Builds the system and adds it to the list
    function buildThermal_callback(~,~)
        
        % Collect the temperature and pressure constraints:
        ThighStr = get(highTempThermalEdit,'String');
        Thigh = str2double(ThighStr);
        TlowStr = get(lowTempThermalEdit,'String');
        Tlow = str2double(TlowStr);
        PlowStr = get(lowPressThermalEdit,'String');
        Plow = str2double(PlowStr);
        
        %Collect the value in the tracking dimension edit box
        trackingAxesStr = get(colecThermalTrackingEdit,'String');
        trackingAxes = str2double(trackingAxesStr);
        
        % For each component listbox, read the string of the currently
        % selected component:
        hxStr = get(hxThermalSelect,'String');
        hx = hxStr{get(hxThermalSelect,'Value')};
        pumpStr = get(pumpThermalSelect,'String');
        pump = pumpStr{get(pumpThermalSelect,'Value')};
        colecStr = get(colecThermalSelect,'String');
        colec = colecStr{get(colecThermalSelect,'Value')};
        fluidStr = get(fluidThermalSelect,'String');
        fluid = fluidStr{get(fluidThermalSelect,'Value')};
        
        
        % This case statement contains an entry for each possible string in
        % the list boxes. Here, each 'componentInput' will be a component
        % object.  For default components the efficiency information
        % supplied in the edit box will be used to create the component, if
        % supplied by the user and valid.
        switch pump
            case 'Pump'
                % If the efficiency box has a valid value (between 0 and
                % 1) this will create a new default component with that eta.
                pumpEta = str2double(get(pumpThermalEtaEdit,'String'));
                if 0 <= pumpEta && pumpEta <= 1
                    pumpInput = Pump(pumpEta);
                else
                    errordlg('An efficiency between 0 and 1 must be specified for the pump');
                end
            otherwise
                errordlg('A classdef for this component does not exist')
        end
        
        switch colec
            % Todo:  Work on these constant effiency cases for each
            % collector/system type
            %             case 'Constant efficiency'
            %                 % If the efficiency box has a valid value (between 0 and
            %                 % 1) this will create a new default component with that eta.
            %                 colecEta = str2double(get(colecThermalEtaEdit,'String'));
            %                 if 0 <= colecEta && colecEta <= 1
            %                     colecInput = CHPCollector(colecEta);
            %                 else
            %                     errordlg('An efficiency between 0 and 1 must be specified for the collector');
            %                 end
            case 'Flat-plate'
                % Specs for Arcon HT-SA 28-10 from 2011 TUV Rheinland
                % certificate.  10067 Wp and 13.57 m^2 gross area
                colecInput = ThermalCollector(0.804, 2.564, 0.005, [1 1 1 0.99 0.97 0.94 0.96 0.72 0], [1 1 1 0.99 0.97 0.94 0.96 0.72 0], 10067, 13.57);
            case 'Evacuated tube'
                % Specs for Kloben Sud Sky CPC from 2011 TUV Rheinland
                % certificate.  SKY 21 CPC 58, 2377 Wp and 3.76 m^2 gross
                % area
                colecInput = TubeCollector(0.718, 0.974, 0.005, [1 1 .99 .97 .94 .87 .78 .62 0], [1 1.02 1.03 1.04 1.04 1.08 1.17 1.38 0], 2377, 3.76);
            case 'Concentrating trough'
                % Specs for NEP Polytrough 1800 from 2012 SPF certificate,
                % 11065 Wp and 21.782 m^2 gross area
                colecInput = ConcentratingThermalCollector(0.689, 0.36, 0.0011, [1 1 1 1 1 1 1 1 1], [0.99 0.98 0.97 0.96 0.93 0.88 0.74 0.46 0], 11065/21.782, 21.782);
            otherwise
                errordlg('A classdef for this component does not exist')
        end
        
        switch hx
            case 'Fluid heat exchanger'
                % If the efficiency box has a valid value (between 0 and
                % 1) this will create a new default component with that eta.
                hxEta = str2double(get(hxThermalEtaEdit,'String'));
                if 0 <= hxEta && hxEta <= 1
                    hxInput = FluidHX(hxEta);
                else
                    errordlg('An efficiency between 0 and 1 must be specified for the condenser');
                end
            otherwise
                errordlg('A classdef for this component does not exist')
        end
        
        switch fluid
            case 'water'
                fluidInput = 'water';
            otherwise
                errordlg('Currently the only working fluid supported is water')
        end
        % Automatically create a name for the system
        set(nameThermal,'String',[colec,' Thermal tracking ',trackingAxesStr,' ',fluid,' Th ',ThighStr,' Tl ',TlowStr,' Pl ',PlowStr]);
        
        % Now build the system
        S = ThermalSystem(pumpInput, colecInput, hxInput, fluidInput, trackingAxes);
        
        % Add the System, the input values, and the system name to the
        % Simulation's SystemArray, InputArray, and SystemNames properties.
        index = length(sim.SystemArray) +1;
        sim.SystemArray{index} = S;
        sim.InputArray{index} = [Thigh Tlow Plow];
        sim.SystemNames{index} = get(nameThermal,'String');
        
        % return to the simPanel
        set(simPanel,'visible','on');
        set(thermalSysPanel,'visible','off');
        
        % set values of simPanel list boxes
        set(sysList,'String',sim.SystemNames);
        %         string = get(propList,'String');
        %         string{index} = num2str(sim.InputArray{index});
        %         set(propList,'String',string);
        
    end

% Builds the system and adds it to the list
    function buildCHP_callback(~,~)
        
        % Collect the temperature and pressure constraints:
        ThighStr = get(highTempCHPEdit,'String');
        Thigh = str2double(ThighStr);
        PhighStr = get(highPressCHPEdit,'String');
        Phigh = str2double(PhighStr);
        PlowStr = get(lowPressCHPEdit,'String');
        Plow = str2double(PlowStr);
        
        
        %Collect the value in the tracking dimension edit box
        trackingAxesStr = get(colecCHPTrackingEdit,'String');
        trackingAxes = str2double(trackingAxesStr);
        
        % For each component listbox, read the string of the currently
        % selected component:
        expanderStr = get(expanderCHPSelect,'String');
        expander = expanderStr{get(expanderCHPSelect,'Value')};
        genStr = get(genCHPSelect,'String');
        gen = genStr{get(genCHPSelect,'Value')};
        condStr = get(condCHPSelect,'String');
        cond = condStr{get(genCHPSelect,'Value')};
        pumpStr = get(pumpCHPSelect,'String');
        pump = pumpStr{get(pumpCHPSelect,'Value')};
        colecStr = get(colecCHPSelect,'String');
        colec = colecStr{get(colecCHPSelect,'Value')};
        fluidStr = get(fluidCHPSelect,'String');
        fluid = fluidStr{get(fluidCHPSelect,'Value')};
        
        
        % This case statement contains an entry for each possible string in
        % the list boxes. Here, each 'componentInput' will be a component
        % object.  For default components the efficiency information
        % supplied in the edit box will be used to create the component, if
        % supplied by the user and valid.
        switch pump
            case 'Pump'
                % If the efficiency box has a valid value (between 0 and
                % 1) this will create a new default component with that eta.
                pumpEta = str2double(get(pumpCHPEtaEdit,'String'));
                if 0 <= pumpEta && pumpEta <= 1
                    pumpInput = Pump(pumpEta);
                else
                    errordlg('An efficiency between 0 and 1 must be specified for the pump');
                end
            otherwise
                errordlg('A classdef for this component does not exist')
        end
        
        switch colec
            %             case 'Constant efficiency'
            %                 % If the efficiency box has a valid value (between 0 and
            %                 % 1) this will create a new default component with that eta.
            %                 colecEta = str2double(get(colecCHPEtaEdit,'String'));
            %                 if 0 <= colecEta && colecEta <= 1
            %                     colecInput = ConcentratingThermalCollector(colecEta);
            %                 else
            %                     errordlg('An efficiency between 0 and 1 must be specified for the collector');
            %                 end
            case 'Evacuated tube'
                % Specs for Kloben Sud Sky CPC from 2011 TUV Rheinland
                % certificate.  SKY 21 CPC 58, 2377 Wp and 3.76 m^2 gross
                % area
                colecInput = TubeCollector(0.718, 0.974, 0.005, [1 1 .99 .97 .94 .87 .78 .62 0], [1 1.02 1.03 1.04 1.04 1.08 1.17 1.38 0], 2377/3.76, 3.76);
            case 'Concentrating trough'
                % Specs for NEP Polytrough 1800 from 2012 SPF certificate,
                % 11065 Wp and 21.782 m^2 gross area
                colecInput = ConcentratingThermalCollector(0.689, 0.36, 0.0011, [1 1 1 1 1 1 1 1 1], [0.99 0.98 0.97 0.96 0.93 0.88 0.74 0.46 0], 11065/21.782, 21.782);
            otherwise
                errordlg('A classdef for this component does not exist')
        end
        
        switch expander
            case 'Expander'
                % If the efficiency box has a valid value (between 0 and
                % 1) this will create a new default component with that eta.
                expanderEtaStr = get(expanderCHPEtaEdit,'String');
                expanderEta = str2double(expanderEtaStr);
                if 0 <= expanderEta && expanderEta <= 1
                    expanderInput = Expander(expanderEta);
                else
                    errordlg('An efficiency between 0 and 1 must be specified for the expander');
                end
            otherwise
                error('A classdef for this component does not exist')
        end
        
        switch cond
            case 'Condenser'
                % If the efficiency box has a valid value (between 0 and
                % 1) this will create a new default component with that eta.
                condEta = str2double(get(condCHPEtaEdit,'String'));
                if 0 <= condEta && condEta <= 1
                    condInput = Condenser(condEta);
                else
                    errordlg('An efficiency between 0 and 1 must be specified for the condenser');
                end
            otherwise
                errordlg('A classdef for this component does not exist')
        end
        
        switch gen
            case 'Generator'
                % If the efficiency box has a valid value (between 0 and
                % 1) this will create a new default component with that eta.
                genEta = str2double(get(genCHPEtaEdit,'String'));
                if 0 <= genEta && genEta <= 1
                    genInput = Generator(genEta);
                else
                    errordlg('An efficiency between 0 and 1 must be specified for the generator');
                end
            otherwise
                errordlg('A classdef for this component does not exist')
        end
        
        switch fluid
            case 'water'
                fluidInput = 'water';
            otherwise
                errordlg('Currently the only working fluid supported is water')
        end
        
        % Automatically create a name for the system
        set(nameCHP,'String',[colec,' CHP tracking ',trackingAxesStr,' ',fluid,' expander ',expanderEtaStr,' Th ',ThighStr,' Ph ',PhighStr,' Pl ',PlowStr]);
        
        % Now build the system
        S = CHPSystem(pumpInput, colecInput, expanderInput, condInput, genInput, fluidInput, trackingAxes);
        
        % Add the System, the input values, and the system name to the
        % Simulation's SystemArray, InputArray, and SystemNames properties.
        index = length(sim.SystemArray) +1;
        sim.SystemArray{index} = S;
        sim.InputArray{index} = [Thigh Phigh Plow];
        sim.SystemNames{index} = get(nameCHP,'String');
        
        % return to the simPanel
        set(simPanel,'visible','on');
        set(CHPsysPanel,'visible','off');
        
        % set values of simPanel list boxes
        set(sysList,'String',sim.SystemNames);
        %         string = get(propList,'String');
        %         string{index} = num2str(sim.InputArray{index});
        %         set(propList,'String',string);
        
    end

    function buildPV_callback(~,~)
        %Collect the value in the tracking dimension edit box
        trackingAxesStr = get(colecPVTrackingEdit,'String');
        trackingAxes = str2double(trackingAxesStr);
        
        % For each component listbox, read the string of the currently
        % selected component:
        
        invStr = get(invPVSelect,'String');
        inv = invStr{get(invPVSelect,'Value')};
        colecStr = get(colecPVSelect,'String');
        colec = colecStr{get(colecPVSelect,'Value')};
        
        
        % This case statement contains an entry for each possible string in
        % the list boxes. Here, each 'componentInput' will be a component
        % object.  For default components the efficiency information
        % supplied in the edit box will be used to create the component, if
        % supplied by the user and valid.
        
        switch colec
            case 'Polycrystalline-Si flat-panel PV'
                colecInput = PVCollector('Si',290/1.94); % Seraphim Solar System SRP-290-6PA from CEC database: area 1.94 m^2, 290 Wp STC
            case 'Monocrystalline-Si flat-panel PV'
                colecInput = PVCollector('Si',327/1.631); % SunPower SPR-327NE-WHT-D from CEC database:  area 1.631 m^2, 327 Wp STC
            case 'CdTe flat-panel PV'
                colecInput = PVCollector('CdTe',90/0.72); % First Solar FS-390 from CEC database: area 0.72 m^2, 90 Wp STC
            case 'CIGS flat-panel PV'
                colecInput = PVCollector('CIGS',150/1.071); % MiaSol MS150GG-02 from CEC database: area 1.071 m^2, 150 Wp STC
            case 'High concentration PV'
                colecInput = CPVCollector(90.4/0.3016,0.3016); % Semprius module from Sandia Memo:  optical aperture area 0.264 m^2, area 0.3016 m^2, 90.4 Wp STC
            otherwise
                errordlg('A classdef for this component does not exist')
        end
        
        switch inv
            case 'Inverter'
                % If the efficiency box has a valid value (between 0 and
                % 1) this will create a new default component with that eta.
                invEtaStr = get(invPVEtaEdit,'String');
                invEta = str2double(invEtaStr);
                if 0 <= invEta && invEta <= 1
                    invInput = Inverter(invEta);
                else
                    errordlg('An efficiency between 0 and 1 must be specified for the inverter');
                end
            otherwise
                errordlg('A classdef for this component does not exist')
        end
        
        % Automatically create a name for the system
        set(namePV,'String',[colec,' ',inv,' ',invEtaStr,' tracking ',trackingAxesStr]);
        
        % Now build the system
        S = PVSystem(colecInput, invInput, trackingAxes);
        
        % Add the System, and the system name to the
        % Simulation's SystemArray, and SystemNames properties.
        index = length(sim.SystemArray) +1;
        sim.SystemArray{index} = S;
        sim.SystemNames{index} = get(namePV,'String');
        
        % return to the simPanel
        set(simPanel,'visible','on');
        set(PVsysPanel,'visible','off');
        
        % set values of simPanel list boxes
        set(sysList,'String',sim.SystemNames);
        %         string = get(propList,'String');
        %         string{index} = num2str(sim.InputArray{index});
        %         set(propList,'String',string);
        
    end

% Builds the system and adds it to the list
    function buildPVT_callback(~,~)
        
        % Collect the temperature and pressure constraints:
        ThighStr = get(highTempPVTEdit,'String');
        Thigh = str2double(ThighStr);
        PhighStr = get(highPressPVTEdit,'String');
        Phigh = str2double(PhighStr);
        PlowStr = get(lowPressPVTEdit,'String');
        Plow = str2double(PlowStr);
        
        %Collect the value in the tracking dimension edit box
        trackingAxesStr = get(colecPVTTrackingEdit,'String');
        trackingAxes = str2double(trackingAxesStr);
        
        % For each component listbox, read the string of the currently
        % selected component:
        expanderStr = get(expanderPVTSelect,'String');
        expander = expanderStr{get(expanderPVTSelect,'Value')};
        genStr = get(genPVTSelect,'String');
        gen = genStr{get(genPVTSelect,'Value')};
        invStr = get(invPVTSelect,'String');
        inv = invStr{get(invPVTSelect,'Value')};
        condStr = get(condPVTSelect,'String');
        cond = condStr{get(genPVTSelect,'Value')};
        pumpStr = get(pumpPVTSelect,'String');
        pump = pumpStr{get(pumpPVTSelect,'Value')};
        colecStr = get(colecPVTSelect,'String');
        colec = colecStr{get(colecPVTSelect,'Value')};
        fluidStr = get(fluidPVTSelect,'String');
        fluid = fluidStr{get(fluidPVTSelect,'Value')};
        
        
        % This case statement contains an entry for each possible string in
        % the list boxes. Here, each 'componentInput' will be a component
        % object.  For default components the efficiency information
        % supplied in the edit box will be used to create the component, if
        % supplied by the user and valid.
        switch pump
            case 'Pump'
                % If the efficiency box has a valid value (between 0 and
                % 1) this will create a new default component with that eta.
                pumpEta = str2double(get(pumpPVTEtaEdit,'String'));
                if 0 <= pumpEta && pumpEta <= 1
                    pumpInput = Pump(pumpEta);
                else
                    errordlg('An efficiency between 0 and 1 must be specified for the pump');
                end
            otherwise
                errordlg('A classdef for this component does not exist')
        end
        
        switch colec
            case 'Concentrating hybrid PVT'
                colecInput = PVTCollector(100);
            otherwise
                errordlg('A classdef for this component does not exist')
        end
        
        switch expander
            case 'Expander'
                % If the efficiency box has a valid value (between 0 and
                % 1) this will create a new default component with that eta.
                expanderEtaStr = get(expanderPVTEtaEdit,'String');
                expanderEta = str2double(expanderEtaStr);
                if 0 <= expanderEta && expanderEta <= 1
                    expanderInput = Expander(expanderEta);
                else
                    errordlg('An efficiency between 0 and 1 must be specified for the expander');
                end
            otherwise
                error('A classdef for this component does not exist')
        end
        
        switch cond
            case 'Condenser'
                % If the efficiency box has a valid value (between 0 and
                % 1) this will create a new default component with that eta.
                condEta = str2double(get(condPVTEtaEdit,'String'));
                if 0 <= condEta && condEta <= 1
                    condInput = Condenser(condEta);
                else
                    errordlg('An efficiency between 0 and 1 must be specified for the condenser');
                end
            otherwise
                errordlg('A classdef for this component does not exist')
        end
        
        switch gen
            case 'Generator'
                % If the efficiency box has a valid value (between 0 and
                % 1) this will create a new default component with that eta.
                genEta = str2double(get(genPVTEtaEdit,'String'));
                if 0 <= genEta && genEta <= 1
                    genInput = Generator(genEta);
                else
                    errordlg('An efficiency between 0 and 1 must be specified for the generator');
                end
            otherwise
                errordlg('A classdef for this component does not exist')
        end
        
        switch inv
            case 'Inverter'
                % If the efficiency box has a valid value (between 0 and
                % 1) this will create a new default component with that eta.
                invEtaStr = get(invPVTEtaEdit,'String');
                invEta = str2double(invEtaStr);
                if 0 <= invEta && invEta <= 1
                    invInput = Inverter(invEta);
                else
                    errordlg('An efficiency between 0 and 1 must be specified for the inverter');
                end
            otherwise
                errordlg('A classdef for this component does not exist')
        end
        
        switch fluid
            case 'water'
                fluidInput = 'water';
            otherwise
                errordlg('Currently the only working fluid supported is water')
        end
        
        % Automatically create a name for the system
        set(namePVT,'String',[colec,' ',inv,' ',invEtaStr,' tracking ',trackingAxesStr,' ',fluid,' expander ',expanderEtaStr,' Th ',ThighStr,' Ph ',PhighStr,' Pl ',PlowStr]);
        
        % Now build the system
        S = PVTSystem(pumpInput, colecInput, expanderInput, condInput, genInput, fluidInput, invInput, trackingAxes);
        
        % Add the System, the input values, and the system name to the
        % Simulation's SystemArray, InputArray, and SystemNames properties.
        index = length(sim.SystemArray) +1;
        sim.SystemArray{index} = S;
        sim.InputArray{index} = [Thigh Phigh Plow];
        sim.SystemNames{index} = get(namePVT,'String');
        
        % return to the simPanel
        set(simPanel,'visible','on');
        set(PVTsysPanel,'visible','off');
        
        % set values of simPanel list boxes
        set(sysList,'String',sim.SystemNames);
        %         string = get(propList,'String');
        %         string{index} = num2str(sim.InputArray{index});
        %         set(propList,'String',string);
        
    end

    function cancel_callback(~,~)
        set(simPanel,'visible','on');
        set(CHPsysPanel,'visible','off');
        set(PVsysPanel,'visible','off');
        set(PVTsysPanel,'visible','off');
        set(thermalSysPanel,'visible','off');
    end

    function calculate_callback(~, ~)
        set(plotButton,'Enable','off');
        set(calculate,'Enable','off');
        set(compare,'Enable','off');
        systems = get(sysList,'Value');
        environments = get(envList,'Value');
        sim.calculate(systems,environments,outputSitesGDX.Value,outputTechGDX.Value);
        set(plotButton,'Enable','on');
        set(compare,'Enable','on');
    end

    function plotButton_callback(~, ~)
        set(calculate,'Enable','off');
        systems = get(sysList,'Value');
        environments = get(envList,'Value');
        sim.plot(systems,environments);
    end

    function compare_callback(~, ~)
        set(calculate,'Enable','off');
        systems = get(sysList,'Value');
        environments = get(envList,'Value');
        sim.compare(systems,environments);
    end

    function disablePlot_callback(~, ~)
        % Disables the plot and compare buttons and enables the calculate
        % button.  To be used whenever the system or environment lists are
        % selected (changed) by the user.
        set(plotButton,'Enable','off');
        set(compare,'Enable','off');
        set(calculate,'Enable','on');
    end

    function importEnvUS_callback(~, ~)
        ok = questdlg('Do you want to load the EnvironmentsUSA.mat file?  If you select "No" all TMY data will be loaded from the original files which takes a long time');
        switch ok
            case 'Yes'
                % Set the Location.
                sim.Location = 'US';
                
                % Load the .mat file with the pregenerated EnvArray and save to
                % the simulation EnvArray structure.
                load('EnvironmentsUSA.mat');
                sim.getSitesFromMat(envArray);
                
            case 'No'
                % Set the Location.
                sim.Location = 'US';
                
                % Read all the TMY data from the original txt/csv files and
                % save to sim.EnvArray
                sim.getSites();
                envArray = sim.EnvArray;
                
                % save the array as a .mat file for future speedy loading.
                % -v7.3 allows saving over 2GB files
                save('EnvironmentsUSA.mat','envArray','-v7.3');
                
            case 'Cancel'
                return
        end
        
        % Disables the plot and compare buttons and enables the calculate
        % button.  To be used whenever the system or environment lists are
        % selected (changed) by the user.
        set(plotButton,'Enable','off');
        set(compare,'Enable','off');
        set(calculate,'Enable','on');
        
        % Deselect all items in the list, grey out the button just selected,
        % activate the other environment button and update the environment
        % list.
        set(envList,'Value',[]);
        set(importEnvUS,'Enable','off');
        set(importEnvEUR,'Enable','on');
        set(envList,'String',sim.EnvNames);
    end

    function importEnvEUR_callback(~, ~)
        
        ok = questdlg('Do you want to load the EnvironmentsEurope.mat file?  If you select "No" all TMY data will be loaded from the original files which takes a long time');
        switch ok
            case 'Yes'
                % Set the Location.
                sim.Location = 'EU';
                
                % Load the .mat file with the pregenerated EnvArray and save to
                % the simulation EnvArray structure.
                load('EnvironmentsEurope.mat');
                sim.getSitesFromMat(envArray);
                
            case 'No'
                % Set the Location.
                sim.Location = 'EU';
                
                % Read all the TMY data from the original txt/csv files
                sim.getSites();
                envArray = sim.EnvArray;
                
                % save the array as a .mat file for future speedy loading.
                % -v7.3 allows saving over 2GB files
                save('EnvironmentsEurope.mat','envArray','-v7.3');
                
            case 'Cancel'
                return
        end
        
        % Disables the plot and compare buttons and enables the calculate
        % button.  To be used whenever the system or environment lists are
        % selected (changed) by the user.
        set(plotButton,'Enable','off');
        set(compare,'Enable','off');
        set(calculate,'Enable','on');
        
        % Deselect all items in the list, grey out the button just selected,
        % activate the other environment button and update the environment
        % list.
        set(envList,'Value',[]);
        set(importEnvEUR,'Enable','off');
        set(importEnvUS,'Enable','on');
        set(envList,'String',sim.EnvNames);
    end
end