function [status, info, headers, data] = importtmydata(~, TMYfilename)

% Imports data from a TMY comma seperated value file, given its filename as
% a string.  Creates three output matrices, one for each of the site's
% identifying info, the headers for the data columns (which are not used),
% and the time-series data columns themselves.

% Open the file.
fid = fopen(TMYfilename);

% Read the first line of the CSV file, importing the site info.
info = textscan(fid, '%f %s %s %f %f %f %f', 1, 'delimiter', ',');

% Read the second line of the CSV file, importing the data header names.
% The data field numbers correspond to the columns in the CSV file, and the
% field numbers given in the TMY data users' manual published by NREL.
% Data field numbers:     1  2  3  4  5  6  7  8  9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68
headers = textscan(fid, '%s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s', 1, 'headerlines', 0, 'delimiter', ',');

% Read every other line of the CSV file, importing the data itself.  Again,
% the data field numbers correspond to the columns in the CSV file, and the
% field numbers given in the TMY data users' manual published by NREL.
% Data field numbers:     1  2  3  4  5  6  7  8  9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68
data =    textscan(fid, '%s %s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %s %f %f %s %f %f %s %f %f %s %f %f %s %f %f %s %f %f %s %f %f %s %f %f %s %f %f %s %f %f %s %f %f %s %f %f %s %f %f %f %s %f', 'headerlines', 0, 'delimiter', ',');

% Close the file, and return the status of that operation.
status = fclose(fid);