function [month, daynum, hour] = processtime(~, data)

% Converts the time stamp as read from the TMY data file ('mm/dd/yyyy' and
% 'HH:MM' strings) to separate numeric fields for month number, day number
% (1 to 365), and hour (0 to 23).
%
% UNITS
% Input data cell matrix including string time stamps, output vectors for
% month, day, and hour.
%
% VECTORIZATION
% Configured for vectorized operations: outputs are vectors.

% Concatenate the string date (a vector in data cell 1) with an underscore
% and the string time (a vector in data cell 2).  Then use the 'datevec'
% function to convert this into a date vector, by specifying the format of
% the string being read in (i.e. 'mm/dd/yyyy_HH:MM').
timevec = datevec(strcat(data{1},'_',data{2}),'mm/dd/yyyy_HH:MM');

% The month is the second column of this time vector.
month = timevec(:,2);

% The day number is not given explicitly in the time vector, so it is found
% by using the 'datenum' function, which gives the number of the day
% starting at Jan-1-0000.  To find the day number within one year, subtract
% the date number for Jan 1 from each other date number and add one.
% Ensure that this is done within a 365-day year (i.e. 2007).
daynum = datenum(2007, timevec(:,2), timevec(:,3)) ...
    - datenum(2007, timevec(1,2), timevec(1,3)) + 1;

% The hour is the fourth column of the time vector.
hour = timevec(:,4);