classdef ThermalSystem < System
    
    properties
        Pump
        Collector
        HeatExchanger
        FluidName
        TrackingAxes
        WpTh
    end
    
    methods
        function sys = ThermalSystem(pump, collector, heatExchanger, fluidName, trackingAxes)
            if nargin == 0
                warning('Null input constructor call: ThermalSystem');
            elseif nargin == 5
                if ~isa(pump,'Pump')
                    error('Please specify a Pump object as the 1st input')
                else
                    sys.Pump = pump;
                end
                
                if ~isa(collector,'ThermalCollector')
                    error('Please specify a ThermalCollector object as the 2nd input')
                else
                    sys.Collector = collector;
                end
                
                if ~isa(heatExchanger,'HeatExchanger')
                    error('Please specify a HeatExchanger object as the 3rd input')
                else
                    sys.HeatExchanger = heatExchanger;
                end
                
                if ~ischar(fluidName)
                    error('Please specify a fluid name as the 4th input')
                else
                    sys.FluidName = fluidName;
                end
                
                if ~((trackingAxes>=0)&&(trackingAxes<=2))
                    error('Please specify the number of tracking axes between 0 (no-tracking) and 2 (2-axis tracking) as the 5th input')
                else
                    sys.TrackingAxes = trackingAxes;
                end
                
                % Calculate rated power as collector rated power times
                % heat exchanger efficiency
                sys.WpTh = sys.Collector.Wp * sys.HeatExchanger.Eta;
                
            else
                error('Not correct number of inputs. Please specify 5 inputs for a ThermalSystem')
            end
            
        end %end constructor
        
    end % end methods block
    
    methods (Access = public)
        [heatIn, heatOut, etaTherm] = calculate(sys, Thigh, Tlow, P);
    end
end