function [] = PlotElinCapacityStacked( mapELINnames, outputColors, conventional, peakingGas, CCS, wind, solar, hydro, geothermal, other, titleText, xLabel, yLabel, lowestOmitLevel )
%PlotElinCapacityStacked Plots a stacked area graph of the capacities of each newly installed generation technology from the ELIN results.
%   Detailed explanation goes here

% Make datasets 2-dimensional (year and total installed capacity for each technology) by summing over
% the extra dimensions and then reducing all single dimensions using the
% squeeze function.
legendConventional = values(mapELINnames,conventional.uels{1,2});
legendPeakingGas = 'peaking natural gas';
legendCCS = values(mapELINnames,CCS.uels{1,2});
legendWind = values(mapELINnames,wind.uels{1,2});
legendSolar = values(mapELINnames,solar.uels{1,1});
legendHydro = values(mapELINnames,hydro.uels{1,2});
legendGeothermal = values(mapELINnames,geothermal.uels{1,2});
legendOther = values(mapELINnames,other.uels{1,2});
%legendStorage = storage.uels{1,1};
%legendTransmission = 'transmission';

xData = str2double(solar.uels{1,3});

conventional = squeeze(sum(sum(conventional.val,3),1))';
peakingGas = squeeze(sum(peakingGas.val,1))';
CCS = squeeze(sum(sum(CCS.val,3),1))';
wind = squeeze(sum(wind.val,1))';
solar = squeeze(sum(solar.val,2))';
hydro = squeeze(sum(hydro.val,1))';
geothermal = squeeze(sum(geothermal.val,1));
other = squeeze(sum(other.val,1))';
% storage = squeeze(sum(storage.val,2))';
%transmission = squeeze(sum(sum(transmission.val,2),1));

% rearrange technologies and group them in the desired output order.
allTechs = [hydro, other(:,4:-1:2), geothermal, wind, solar(:,6:2:10), solar(:,7:2:11), solar(:,1:5), conventional(:,5:7), CCS, conventional(:,1:3), peakingGas, conventional(:,4), conventional(:,8)];
allLegends = [legendHydro, legendOther(:,4:-1:2), legendGeothermal, legendWind, legendSolar(:,6:2:10), legendSolar(:,7:2:11), legendSolar(:,1:5), legendConventional(:,5:7), legendCCS, legendConventional(:,1:3), legendPeakingGas, legendConventional(:,4), legendConventional(:,8)];

%first remove existing technology labels from the color list
outputColors = [outputColors(1:6,:); outputColors(8:16,:); outputColors(18:27,:); outputColors(29:length(outputColors)-3,:)];

%find technologies with no new capacity under time period and remove
%corresponding columns from legend and area plot, and the output colors list.
nonZeroColumns = find(sum(allTechs,1)>lowestOmitLevel*sum(sum(allTechs)));
outputColors=outputColors(nonZeroColumns,:);

fig = figure('NumberTitle','off','Name',titleText);

stackedArea = area(allTechs(:,nonZeroColumns));
for i=1:length(stackedArea)
    stackedArea(i).FaceColor = outputColors(i,:);
end

set(stackedArea,'XData',xData);

xlabel(xLabel);
ylabel(yLabel);

% flip the data and legend list left-right to get the order of the legend to match the stacked area plot
legend(fliplr(stackedArea), fliplr(allLegends(:,nonZeroColumns)), 'Location','Best','interpreter','none');

%colormap('linspecer');
saveas(fig,[titleText '.eps'],'epsc');
saveas(fig,[titleText '.png']);
saveas(fig,[titleText '.fig']);

end

