function [] = PlotElinCapacityTransmissionStorage( mapELINnames, outputColors, transmission, storage, titleText, xLabel, yLabelTransmission, yLabelStorage)
%PlotElinCapacityTransmissionStorage plots new installed capacity of
%transmission and storage from the ELIN results.
%   Detailed explanation goes here

% Make datasets 2-dimensional (year and total installed capacity for each technology) by summing over
% the extra dimensions and then reducing all single dimensions using the
% squeeze function.
TeratoGiga = 1000;

legendTransmission = {'transmission (GWp)'};
legendStorage = values(mapELINnames,storage.uels{1,1});

% last three columns in colormap are transmission and storage
outputColorTrans = outputColors(length(outputColors)-2,:);
outputColorsStorage = outputColors(length(outputColors)-1:end,:);

xData = str2double(storage.uels{1,3});

transmission = squeeze(sum(sum(transmission.val,2),1));
storage = squeeze(sum(storage.val,2))'*TeratoGiga;

fig = figure('NumberTitle','off','Name',titleText);

lineTransmission = line(xData, transmission, 'color', outputColorTrans, 'linewidth', 4);
%colormap(linspecer);

xlabel(xLabel);
ylabel(yLabelTransmission);

%find storage technologies with no new capacity under time period and remove
%corresponding columns from legend and area plot.
nonZeroColumnsStorage = find(sum(storage,1));

% now add another axis for the storage
% if there is no storage invested in at all don't plot it
if ~isempty(nonZeroColumnsStorage)
    % Add an axis for the storage and set it to the same position
    % as the transmission axes, but put the y-axis on the right.
    
    % set the colororder of the storage technologies before plotting;
    set(0,'DefaultAxesColorOrder',outputColorsStorage(nonZeroColumnsStorage,:));
    
    %axStorage =
    axes('Position',get(gca, 'Position'),...
        'XAxisLocation','bottom',...
        'YAxisLocation','right',...
        'Color','none');
    
    lineStorage = line(xData, storage(:,nonZeroColumnsStorage), 'linewidth', 4);
    
    %     set(lineStorage,'XData',xData,'color','r');
    ylabel(yLabelStorage);
    
    % flip the data and legend list left-right to get the order of the legend to match the stacked area plot
    
    legend(fliplr([lineStorage',lineTransmission]), fliplr([legendStorage(:,nonZeroColumnsStorage),legendTransmission]), 'Location','northwest','interpreter','none');
    
else
    % if there is no storage invested in at all, the legend will not show it
    legend(lineTransmission, legendTransmission, 'Location','northwest','interpreter','none');
end

saveas(fig,[titleText '.eps'],'epsc');
saveas(fig,[titleText '.png']);
saveas(fig,[titleText '.fig']);

% set default colororder back to factory
set(0,'DefaultAxesColorOrder','factory');

end

