function [] = PlotElinCosts( mapELINnames, outputColors, investmentWind, investmentSolar, investmentStorage, OMwind, OMsolar, titleTextInvestment, titleTextOM, xLabel, yLabelGenCost, yLabelStorageCost, yLabelCapacity )
%PlotElinCosts plots the investment costs of wind, solar and storage with
%investment cost learning curves from ELIN output data.
%   Detailed explanation goes here

% Make datasets 2-dimensional (year and total installed capacity for each technology) by summing over
% the extra dimensions and then reducing all single dimensions using the
% squeeze function.
TeratoGiga = 1000;

legendWind = {'wind - onshore', 'wind - offshore'};
legendSolar = values(mapELINnames,investmentSolar.uels{1,1}([1,4,5,6,7]));
legendStorage = values(mapELINnames,investmentStorage.uels{1,1});

allGenerationLegends = [legendWind, legendSolar];
allOMLegends = [legendWind, legendSolar];

xData = str2double(investmentStorage.uels{1,3});

investmentWind = squeeze(sum(investmentWind.val(1,8:9,:,:),3))';
investmentSolar = squeeze(sum(investmentSolar.val([1,4,5,6,7],1,:,:),3))';
investmentStorage = squeeze(investmentStorage.val(:,1,:))'/TeratoGiga;

OMwind = squeeze(sum(OMwind.val(1,8:9,:,:),3))';
OMsolar = squeeze(sum(OMsolar.val([1,4,5,6,7],1,:,:),3))';

allGenerationCosts = [investmentWind, investmentSolar];
allOMCosts = [OMwind, OMsolar];

%first remove irrelevant technologies from the color list so that the
%remaining colors match the allInvestmentCosts and allOMCosts figures.
outputColorsGeneration = [outputColors(15:16,:); outputColors(24,:); outputColors(27,:); outputColors(29,:); outputColors(18,:); outputColors(21,:)];
outputColorsStorage = outputColors(45:46,:);
outputColorsOM = outputColorsGeneration;

% sort columns in descending order by cost at first year.
[~, sortedInd] = sort(allGenerationCosts(1,:),'descend');
sortedGenerationCosts = allGenerationCosts(:,sortedInd);
sortedGenerationLegends = allGenerationLegends(:,sortedInd);
sortedOutputColorsGen = outputColorsGeneration(sortedInd,:);

% 

% set the colororder of the lines before plotting;
set(0,'DefaultAxesColorOrder',sortedOutputColorsGen);

% investment costs plot
fig = figure('NumberTitle','off','Name',titleTextInvestment);

subplot(2,1,1)
lineGenerationCosts = plot(xData, sortedGenerationCosts);
ylabel(yLabelGenCost);
legend(lineGenerationCosts, sortedGenerationLegends, 'location', 'northeast', 'interpreter','none');

% set the colororder of the lines before plotting;
set(0,'DefaultAxesColorOrder',outputColorsStorage);
subplot(2,1,2)

lineStorageCosts = plot(xData, investmentStorage);
xlabel(xLabel);
ylabel(yLabelStorageCost);
legend(lineStorageCosts, legendStorage, 'location', 'northeast', 'interpreter','none');

saveas(fig,[titleTextInvestment '.eps'],'epsc');
saveas(fig,[titleTextInvestment '.png']);
saveas(fig,[titleTextInvestment '.fig']);

% OM costs plot

% sort columns in descending order by cost at first year.
[~, sortedInd] = sort(allOMCosts(1,:),'descend');
sortedOMCosts = allOMCosts(:,sortedInd);
sortedOMLegends = allOMLegends(:,sortedInd);
sortedOutputColorsOM = outputColorsOM(sortedInd,:);

% set the colororder of the lines before plotting;
set(0,'DefaultAxesColorOrder',sortedOutputColorsOM);

fig = figure('NumberTitle','off','Name',titleTextOM);

lineOMandStorageCosts = line(xData, sortedOMCosts);
xlabel(xLabel);
ylabel(yLabelCapacity);

legend(lineOMandStorageCosts, sortedOMLegends, 'Location','best','interpreter','none');

saveas(fig,[titleTextOM '.eps'],'epsc');
saveas(fig,[titleTextOM '.png']);
saveas(fig,[titleTextOM '.fig']);

% set default colororder back to factory
set(0,'DefaultAxesColorOrder','factory');
end

