function [] = PlotElinElectricityStacked( mapELINnames, outputColors, existingConventional, newConventional, newPeakingGas, newCCS, existingWind, newWind, existingSolar, newSolar, existingRunOfRiverHydro, newRunOfRiverHydro, existingRegulatedHydro, newRegulatedHydro, newGeothermal, existingOther, newOther, storageIn, storageOut, existingTransmissionImport, newTransmissionImport, titleText, xLabel, yLabel, lowestOmitLevel)

%%PlotElinElectricityStacked plots a stacked area graph of the total electricity generation, transmission, and storage from the ELIN results.
%   Detailed explanation goes here

% Make datasets 2-dimensional (year and total installed capacity for each technology) by summing over
% the extra dimensions and then reducing all single dimensions using the
% squeeze function.
legendRunOfRiverHydro = 'hydro - run of river';
legendRegulatedHydro = 'hydro - regulated';
legendOther = values(mapELINnames,newOther.uels{1,2});
legendGeothermal = values(mapELINnames,newGeothermal.uels{1,2});
legendExistingWind = 'wind - existing';
legendNewWind = values(mapELINnames,newWind.uels{1,2});
legendExistingSolar = 'PV - existing';
legendNewSolar = values(mapELINnames,newSolar.uels{1,1});
legendConventional = values(mapELINnames,newConventional.uels{1,2});
legendCCS = values(mapELINnames,newCCS.uels{1,2});
legendPeakingGas = 'peaking natural gas';
legendStorage = values(mapELINnames,storageOut.uels{1,1});
legendTransmission = 'transmission';

% set the years for x data range
xData = str2double(newSolar.uels{1,3});

hydroRunOfRiver = squeeze(sum(existingRunOfRiverHydro.val,1)+sum(newRunOfRiverHydro.val,1))';
hydroRegulated = squeeze(sum(existingRegulatedHydro.val,1)+sum(newRegulatedHydro.val,1))';
other = squeeze(sum(existingOther.val,1)+sum(newOther.val,1))';
geothermal = squeeze(sum(newGeothermal.val,1));
existingWind = sum(existingWind.val,1)';
newWind = squeeze(sum(newWind.val,1))';
existingSolar = sum(existingSolar.val,1)';
newSolar = squeeze(sum(newSolar.val,2))';
conventional = squeeze(sum(sum(existingConventional.val,3),1)+sum(sum(newConventional.val,3),1))';
CCS = squeeze(sum(sum(newCCS.val,3),1))';
peakingGas = squeeze(sum(newPeakingGas.val,1))';
transmission = squeeze(sum(sum(existingTransmissionImport.val,3),1)+sum(sum(newTransmissionImport.val,3),1))';
storageOut = squeeze(sum(sum(storageOut.val,4),2))';

% rearrange technologies and group them in the desired output order.
allTechs = [hydroRunOfRiver, hydroRegulated, other(:,4:-1:2), geothermal, existingWind, newWind, existingSolar, newSolar(:,6:2:10), newSolar(:,7:2:11), newSolar(:,1:4), other(:,1), newSolar(:,5), conventional(:,5:7), CCS, conventional(:,1:3), peakingGas, conventional(:,4), conventional(:,8)];
allLegends = [legendRunOfRiverHydro, legendRegulatedHydro, legendOther(:,4:-1:2), legendGeothermal, legendExistingWind, legendNewWind, legendExistingSolar, legendNewSolar(:,6:2:10), legendNewSolar(:,7:2:11), legendNewSolar(:,1:4), legendOther(:,1), legendNewSolar(:,5), legendConventional(:,5:7), legendCCS, legendConventional(:,1:3), legendPeakingGas, legendConventional(:,4), legendConventional(:,8)];

% separate out transmission and storage data for easy processing
allTransStorage = [transmission, storageOut];
allLegendsTransStorage = [legendTransmission, legendStorage];

%find technologies with no electricity generation under time period and remove
%corresponding columns from legend and area plot, and the output colors list.
nonZeroColumns = find(sum(allTechs,1)>lowestOmitLevel*sum(sum(allTechs)));
outputColorsTechs=outputColors(nonZeroColumns,:);

%find transmission or storage technologies with no new capacity under time period and remove
%corresponding columns from legend and area plot.
nonZeroColumnsTransStorage = find(sum(allTransStorage,1));
% last three columns in colormap are transmission and storage
outputColorsTransStorage = outputColors(length(outputColors)-2:length(outputColors),:);

% set the colororder of the transmission and storage technologies before plotting;
set(0,'DefaultAxesColorOrder',outputColorsTransStorage(nonZeroColumnsTransStorage,:));

fig = figure('NumberTitle','off','Name',titleText);

stackedArea = area(allTechs(:,nonZeroColumns));
for i=1:length(stackedArea)
    stackedArea(i).FaceColor = outputColorsTechs(i,:);
end
set(stackedArea,'XData',xData);
xlabel(xLabel);
ylabel(yLabel);

%%%%%%%% add lines for transmission and storage

lineTransStorage = line(xData, allTransStorage(:,nonZeroColumnsTransStorage),'linewidth',4);

% % if there is no storage energy, don't plot it
% if ~isempty(nonZeroColumnsStorage)
%     % add line(s) for storage energy
%     lineStorage = line(xData, storageOut(:,nonZeroColumnsStorage),'color','r','linewidth',4);
%     
%     % create the legend with only technologies with new capacity plus storage
%     % and transmission.
%     legend(fliplr([stackedArea,lineStorage',lineTransmission]), fliplr([allLegends(:,nonZeroColumns),legendStorage(:,nonZeroColumnsStorage),legendTransmission]), 'Location','bestoutside','interpreter','none');
% else

% flip the data and legend list left-right to get the order of the legend
% to match the stacked area plot, and create the legend with both the area
% plot and the line plots included.
legend(fliplr([stackedArea,lineTransStorage']), fliplr([allLegends(:,nonZeroColumns), allLegendsTransStorage(:,nonZeroColumnsTransStorage)]), 'Location','bestoutside','interpreter','none');
% end

% colormap('linspecer');

%uncomment next 3 lines to save figures in various formats
%saveas(fig,[titleText '.eps'], 'epsc');
%saveas(fig,[titleText '.png']);
%saveas(fig,[titleText '.fig']);

save('plotElectricityResults.mat'); 

% set default colororder back to factory
set(0,'DefaultAxesColorOrder','factory');
end

