function [] = PlotElinMarginalPrices( costEl, costCO2, titleText, xLabel, yLabel)
%PlotElinMarginalPrices plots marginal prices for electricity in every
%region plus the european price for carbon.
%   Detailed explanation goes here

MegatoKilo = 1000;

legendEl = costEl.uels{1,1};
legendCO2 = {'CO2 (EUR/kg)'};

allLegends = [legendEl, legendCO2];

xData = str2double(costEl.uels{1,2});

% transpose rows and columns of el prices to put regions in columns.  Convert from cost
% per MWh and ton to KWh and kg.
costEl = costEl.val'/MegatoKilo;
costCO2 = costCO2.val/MegatoKilo;

allPrices = [costEl, costCO2];

% sort columns in descending order by cost at first year.
[~, sortedInd] = sort(allPrices(1,:),'descend');
sortedPrices = allPrices(:,sortedInd);
sortedLegends = allLegends(:,sortedInd);

% create the figure
fig = figure('NumberTitle','off','Name',titleText);

% plot the line on the current axis
linePrices = line(xData, sortedPrices);

% add the axes labels
xlabel(xLabel);
ylabel(yLabel);

colormap(linspecer);

% create the legend
legend(linePrices, sortedLegends, 'Location','bestoutside','interpreter','none');

% save the figures to various image formats
saveas(fig,[titleText '.eps'],'epsc');
saveas(fig,[titleText '.png']);
saveas(fig,[titleText '.fig']);

end

