function [] = PlotElinPlantEfficiencies( mapELINnames, outputColors, plantEfficiencyCCS, plantEfficiencyConventional, titleText, xLabel, yLabel)
%PlotElinPlantEfficiencies plots efficiency of conventional plants (and
%nuclear) over time.
%   Detailed explanation goes here

legendConventional = values(mapELINnames, plantEfficiencyConventional.uels{1});
legendCCS = values(mapELINnames, plantEfficiencyCCS.uels{1});

allLegends = [legendConventional, legendCCS];
outputColors = [outputColors(38:40,:); outputColors(42,:); outputColors(30:32,:); outputColors(43,:); outputColors(33:37,:)];

xData = str2double(plantEfficiencyConventional.uels{3});

% create one figure for each type of plant (condensing, CHP,
% backpressure) with all fuel types on each figure.
for i=1:length(plantEfficiencyConventional.uels{2})
    
    % transpose rows and columns of el prices to put regions in columns.  Convert from cost
    % per MWh and ton to KWh and kg.
    etaConventional = squeeze(plantEfficiencyConventional.val(:,i,:))';
    etaCCS = squeeze(plantEfficiencyCCS.val(:,i,:))';
    
    allEtas = [etaConventional, etaCCS];
    
    % only coal, gas, oil and biomass are allowable fuels for backpressure
% plants in ELIN, so adjust variables accordingly so output is only for
% these technologies.
    if (strcmp(plantEfficiencyConventional.uels{2}{i},'BP'))
        allLegends = legendConventional([1 2 3 4 6]);
        allEtas = etaConventional(:,[1 2 3 4 6]);
        outputColors = outputColors([1 2 3 4 6],:);
    end
    
    % sort columns in descending order by value at first year.
    [~, sortedInd] = sort(allEtas(1,:),'descend');
    sortedEtas = allEtas(:,sortedInd);
    sortedLegends = allLegends(:,sortedInd);
    sortedOutputColors = outputColors(sortedInd,:);
    
    figTitle = [mapELINnames(plantEfficiencyConventional.uels{2}{i}), ' -- ', titleText];
    
    % set the colororder of the lines before plotting;
    set(0,'DefaultAxesColorOrder',sortedOutputColors);
    
    % create the figure
    fig = figure('NumberTitle','off','Name',figTitle);
    
    % plot the line on the current axis
    linePrices = line(xData, sortedEtas, 'linewidth', 2);
    
    % add the axes labels
    xlabel(xLabel);
    ylabel(yLabel);
    
    colormap(linspecer);
    
    % create the legend
    legend(linePrices, sortedLegends, 'Location','bestoutside','interpreter','none');
    
    % save the figures to eps, png, tif and fig format
    saveas(fig,[figTitle '.eps'],'epsc');
    saveas(fig,[figTitle '.png']);
    saveas(fig,[figTitle '.fig']);
    
end

% set default colororder back to factory
set(0,'DefaultAxesColorOrder','factory');

end

