function [ ] = PlotElinResults (  marginalCostElWeightedAve, marginalCostElTimeStep, marginalCostCO2, costSupplyCurveFossil, costSupplyCurveBio, plantEfficiencyConventional, plantEfficiencyCCS, investmentCostWind, OMcostWind, investmentCostSolar, OMcostSolar, investmentCostStorage, capacityFactorConventional, capacityFactorPeakingGas, capacityFactorCCS, capacityFactorExistingWind, capacityFactorNewWind, capacityFactorExistingSolar, capacityFactorNewSolar, capacityFactorHydro, capacityFactorGeothermal, capacityFactorOthers, solarSitestoCountries, potentialCapacityWind, potentialAreaCentralizedSolar, potentialAreaBuildingSolar, installedAreaCentralizedSolar, installedAreaBuildingSolar, totalCost, totalProductionCost, totalInvestmentCost, electricity, electricityRenewable, adjustedMaxLoad, totalCO2emissions, upperLimitCO2emissions, storageLevel, storageIn, storageOut, capacityStorage, capacityNewConventional, capacityNewPeakingGas, capacityNewCCS, capacityNewWind, capacityNewSolar, capacityNewHydro, capacityNewGeothermal, capacityNewOther, electricityExistingConventional, electricityNewConventional, electricityNewPeakingGas, electricityNewCCS, electricityExistingWind, electricityNewWind, electricityExistingSolar, electricityNewSolar, electricityExistingRunOfRiverHydro, electricityNewRunOfRiverHydro, electricityExistingRegulatedHydro, electricityNewRegulatedHydro, electricityNewGeothermal, electricityExistingOther, electricityNewOther, importExistingTransmission, importNewTransmission, exportExistingTransmission, exportNewTransmission, capacityNewTransmission, totalHeatExistingCHP, totalHeatNewCHP, totalFuelExistingConventional, totalFuelNewConventional, totalFuelNewPeakingGas, totalFuelNewCCS )
%PlotElinResults plots the results of the ELIN run after being read in to
%structures using ReadELINgdx.
%   Detailed explanation goes here
close all;
%clear;
%load('ElinOutput.mat')

% create ELIN name to output name mapping, and a matrix containing a standard RGB colorspec for each
% technology to allow the technology colors to be the same across plots. 
% first read in the RGB colormap and technology names from a text file.
[outputNames, outputColors] = readColormap('colors.txt');
% mapELINcolors = containers.Map(technologyNames, outputColors);
ELINNames = {'Condens'; 'CHP'; 'BP'; 'run_riv'; 'reg'; 'Small_hydro'; 'WV'; 'T'; 'GEO'; 'wind - existing'; 'onwind10'; 'onwind125'; 'onwind15'; 'onwind175'; 'onwind20'; 'onwind25'; 'onwind30'; 'onwind35'; 'offwind'; 'PV - existing'; 'fixed_building_monoSi'; 'fixed_building_CdTe'; 'fixed_building_CIGS'; 'fixed_utility_monoSi'; 'fixed_utility_CdTe'; 'fixed_utility_CIGS'; 'tracking_monoSi'; 'tracking_CdTe'; 'tracking_CIGS'; 'tracking_HCPV'; 'STH'; 'tracking_CSP'; 'P'; 'W'; 'WA'; 'BCCS'; 'HCCS'; 'GCCS'; 'BWCCS'; 'HWCCS'; 'B'; 'H'; 'G'; 'peaking natural gas'; 'O'; 'U'; 'transmission'; 'battery'; 'TES'};
% add a few technology names not associated with any color map but that are
% used in some output graphs.
outputNames = [{'condensing plant'; 'combined heat and power (CHP) plant'; 'back pressure plant'}; outputNames];
mapELINnames = containers.Map(ELINNames,outputNames);

PlotElinCapacityStacked( mapELINnames, outputColors, capacityNewConventional, capacityNewPeakingGas, capacityNewCCS, capacityNewWind, capacityNewSolar, capacityNewHydro, capacityNewGeothermal, capacityNewOther, 'New capacity of electrical generation to 2050', 'year', 'GWp', 0.001);
PlotElinCapacityTransmissionStorage( mapELINnames, outputColors, capacityNewTransmission, capacityStorage, 'Total new capacity of electrical transmission and storage', 'year', 'GWp', 'GWh');
PlotElinElectricityStacked( mapELINnames, outputColors, electricityExistingConventional, electricityNewConventional, electricityNewPeakingGas, electricityNewCCS, electricityExistingWind, electricityNewWind, electricityExistingSolar, electricityNewSolar, electricityExistingRunOfRiverHydro, electricityNewRunOfRiverHydro, electricityExistingRegulatedHydro, electricityNewRegulatedHydro, electricityNewGeothermal, electricityExistingOther, electricityNewOther, storageIn, storageOut, importExistingTransmission, importNewTransmission, 'Energy from electrical generation, transmission and storage to 2050', 'year', 'TWh',0.001);
PlotElinSolarMap( mapELINnames, capacityNewSolar, 0.5, 'Capacity density of solar installations in 2050', 'Wp / m^2', -1, -1 );
PlotElinWindMap( capacityNewWind, 35.375, 70.875, -23.625, 29.875, 'Capacity density of wind installations in 2050', 'Wp / m^2', -1, -1 );
PlotElinCosts( mapELINnames, outputColors, investmentCostWind, investmentCostSolar, investmentCostStorage, OMcostWind, OMcostSolar, 'Investment costs of generation technologies and storage with learning curves', 'OM costs of technologies with learning curves', 'year', ' / kWp', ' / kWh', ' / kWp' );
PlotElinMarginalPrices( marginalCostElWeightedAve, marginalCostCO2, 'Marginal prices of electricity and carbon dioxide', 'year', 'EUR/kWh (electricity) and EUR/kg (CO2)');
PlotElinCarbonEmissions( totalCO2emissions, upperLimitCO2emissions, 'Total CO2 emissions compared to ELIN limits', 'year', 'kg CO2' );
PlotElinPlantEfficiencies( mapELINnames, outputColors, plantEfficiencyCCS, plantEfficiencyConventional, 'New power plant efficiencies over time for conventional technologies and CCS', 'year', 'Eta');
end

