function [] = PlotElinSolarWind2050()

%%PlotElinSolarWind2050 plots a series of bar graphs of the total electricity generation from solar and wind in year 2050 from all the ELIN sensitivity runs and base case.
%   Detailed explanation goes here

% Read in base case no net metering climate market output
load('D:\Users\norwood\Dropbox (SustainableBuilding)\data elin\results\Base no net metering climate market\plotElectricityResults.mat', 'allTechs', 'xData', 'xLabel', 'yLabel', 'allLegends', 'nonZeroColumns');
solWindTechsBase = [sum(allTechs(41,7:16))/sum(allTechs(41,:)),sum(allTechs(41,17:29))/sum(allTechs(41,:))];

%Read in solar net metering sens output
load('D:\Users\norwood\Dropbox (SustainableBuilding)\data elin\results\Solar net metering\plotElectricityResults.mat', 'allTechs', 'xData', 'xLabel', 'yLabel', 'allLegends', 'nonZeroColumns');
solWindTechsSolarNetMeter = [sum(allTechs(41,7:16))/sum(allTechs(41,:)),sum(allTechs(41,17:29))/sum(allTechs(41,:))];

%Read in PV price sens output
load('D:\Users\norwood\Dropbox (SustainableBuilding)\data elin\results\PV price sens\plotElectricityResults.mat', 'allTechs', 'xData', 'xLabel', 'yLabel', 'allLegends', 'nonZeroColumns');
solWindTechsPVprice = [sum(allTechs(41,7:16))/sum(allTechs(41,:)),sum(allTechs(41,17:29))/sum(allTechs(41,:))];

%Read in HCPV price sens output
load('D:\Users\norwood\Dropbox (SustainableBuilding)\data elin\results\HCPV price sens\plotElectricityResults.mat', 'allTechs', 'xData', 'xLabel', 'yLabel', 'allLegends', 'nonZeroColumns');
solWindTechsHCPVprice = [sum(allTechs(41,7:16))/sum(allTechs(41,:)),sum(allTechs(41,17:29))/sum(allTechs(41,:))];

%Read in CSP price sens with OM output
load('D:\Users\norwood\Dropbox (SustainableBuilding)\data elin\results\CSP price sens with OM\plotElectricityResults.mat', 'allTechs', 'xData', 'xLabel', 'yLabel', 'allLegends', 'nonZeroColumns');
solWindTechsCSPprice = [sum(allTechs(41,7:16))/sum(allTechs(41,:)),sum(allTechs(41,17:29))/sum(allTechs(41,:))];

%Read in Wind price sens output
load('D:\Users\norwood\Dropbox (SustainableBuilding)\data elin\results\Wind price sens\plotElectricityResults.mat', 'allTechs', 'xData', 'xLabel', 'yLabel', 'allLegends', 'nonZeroColumns');
solWindTechsWindPrice = [sum(allTechs(41,7:16))/sum(allTechs(41,:)),sum(allTechs(41,17:29))/sum(allTechs(41,:))];

%Read in storage price sens output
load('D:\Users\norwood\Dropbox (SustainableBuilding)\data elin\results\Storage price sens\plotElectricityResults.mat', 'allTechs', 'xData', 'xLabel', 'yLabel', 'allLegends', 'nonZeroColumns');
solWindTechsStoragePrice = [sum(allTechs(41,7:16))/sum(allTechs(41,:)),sum(allTechs(41,17:29))/sum(allTechs(41,:))];

%Read in solar low intensity sens output
load('D:\Users\norwood\Dropbox (SustainableBuilding)\data elin\results\Solar low intensity sens\plotElectricityResults.mat', 'allTechs', 'xData', 'xLabel', 'yLabel', 'allLegends', 'nonZeroColumns');
solWindTechsSolarLowIntensity = [sum(allTechs(41,7:16))/sum(allTechs(41,:)),sum(allTechs(41,17:29))/sum(allTechs(41,:))];

%Read in Wind low intensity sens output
load('D:\Users\norwood\Dropbox (SustainableBuilding)\data elin\results\Wind low intensity sens\plotElectricityResults.mat', 'allTechs', 'xData', 'xLabel', 'yLabel', 'allLegends', 'nonZeroColumns');
solWindTechsWindLowIntensity = [sum(allTechs(41,7:16))/sum(allTechs(41,:)),sum(allTechs(41,17:29))/sum(allTechs(41,:))];

titleText = 'Solar and Wind share of total electricity production in 2050 for base and sensitivity runs';
fig = figure('NumberTitle','off','Name',titleText);

allTechsSolarWind = [fliplr(solWindTechsBase); fliplr(solWindTechsSolarNetMeter); fliplr(solWindTechsPVprice); fliplr(solWindTechsHCPVprice); fliplr(solWindTechsCSPprice); fliplr(solWindTechsWindPrice); fliplr(solWindTechsStoragePrice); fliplr(solWindTechsSolarLowIntensity); fliplr(solWindTechsWindLowIntensity)];
legendsSolarWind = {'solar', 'wind'};
% making valueset sets the order of the xData, otherwise the bars
% will be in some other order
valueset = {'base', 'solar net metering', 'lower solar cost', 'lower HCPV cost', 'lower CSP cost', 'lower wind cost', 'lower storage cost', 'lower allowed solar density', 'lower allowed wind density'};
xData = categorical({'base', 'solar net metering', 'lower solar cost', 'lower HCPV cost', 'lower CSP cost', 'lower wind cost', 'lower storage cost', 'lower allowed solar density', 'lower allowed wind density'}, valueset);

stackedBar = bar(xData, allTechsSolarWind, 'stacked');

% change colors and width of the bars
stackedBar(1).BarWidth = 0.6;
stackedBar(2).BarWidth = 0.6;
stackedBar(1).FaceColor = 'yellow';
stackedBar(2).FaceColor = 'green';

% flip the data and legend list left-right to get the order of the legend
% to match the stacked area plot.
legend(fliplr(stackedBar), fliplr(legendsSolarWind), 'Location','bestoutside','interpreter','none');
xlabel('scenarios');
ylabel('fraction of total electricity');

saveas(fig,[titleText '.eps'], 'epsc');
saveas(fig,[titleText '.png']);
saveas(fig,[titleText '.fig']);

end

